% Auto-generated chapter 37 for muslim
% Hadiths in this chapter: 184

\hadithdefcmd{muslim}{5385}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ زَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِي يَشْرَبُ فِي آنِيَةِ الْفِضَّةِ إِنَّمَا يُجَرْجِرُ فِي بَطْنِهِ نَارَ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{5385}\hadithtrans{Umm Salama, the wife of Allah's Apostle (ﷺ), said:He who drinks in the vessel of silver in fact drinks down in his belly the fire of Hell}}
\hadithdefcmd{muslim}{5386}{وَحَدَّثَنَاهُ قُتَيْبَةُ، وَمُحَمَّدُ بْنُ رُمْحٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنِيهِ عَلِيُّ بْنُ حُجْرٍ، السَّعْدِيُّ حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ، بْنُ بِشْرٍ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي، شَيْبَةَ وَالْوَلِيدُ بْنُ شُجَاعٍ قَالاَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ، أَبِي بَكْرٍ الْمُقَدَّمِيُّ حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، ح . وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرٌ، - يَعْنِي ابْنَ حَازِمٍ - عَنْ عَبْدِ الرَّحْمَنِ، السَّرَّاجِ كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، ‏.‏ بِمِثْلِ حَدِيثِ مَالِكِ بْنِ أَنَسٍ بِإِسْنَادِهِ عَنْ نَافِعٍ، وَزَادَ، فِي حَدِيثِ عَلِيِّ بْنِ مُسْهِرٍ عَنْ عُبَيْدِ اللَّهِ، ‏ "‏ أَنَّ الَّذِي، يَأْكُلُ أَوْ يَشْرَبُ فِي آنِيَةِ الْفِضَّةِ وَالذَّهَبِ ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِ أَحَدٍ مِنْهُمْ ذِكْرُ الأَكْلِ وَالذَّهَبِ إِلاَّ فِي حَدِيثِ ابْنِ مُسْهِرٍ ‏.‏\hadithno{5386}\hadithtrans{This hadith has been narrated through other chains of transmitters. The hadith of Ibn Mushir on the authority of 'Ubaidullah it is as:He who eats or drinks in the vessel of silver and gold, - but there is no mention in any one of the other chains of the words pertaining to eating and gold}}
\hadithdefcmd{muslim}{5387}{وَحَدَّثَنِي زَيْدُ بْنُ يَزِيدَ أَبُو مَعْنٍ الرَّقَاشِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عُثْمَانَ، - يَعْنِي ابْنَ مُرَّةَ - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ خَالَتِهِ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَرِبَ فِي إِنَاءٍ مِنْ ذَهَبٍ أَوْ فِضَّةٍ فَإِنَّمَا يُجَرْجِرُ فِي بَطْنِهِ نَارًا مِنْ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{5387}\hadithtrans{Abd al-Rahman reported on the authority of his mother's sister Umm Salama who said that Allah's Messenger (ﷺ) said:He who drank in vessels of gold or silver he in fact drank down in his belly the fire of Hell}}
\hadithdefcmd{muslim}{5388}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَشْعَثُ، حَدَّثَنِي مُعَاوِيَةُ بْنُ سُوَيْدِ، بْنِ مُقَرِّنٍ قَالَ دَخَلْتُ عَلَى الْبَرَاءِ بْنِ عَازِبٍ فَسَمِعْتُهُ يَقُولُ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعٍ وَنَهَانَا عَنْ سَبْعٍ أَمَرَنَا بِعِيَادَةِ الْمَرِيضِ وَاتِّبَاعِ الْجَنَازَةِ وَتَشْمِيتِ الْعَاطِسِ وَإِبْرَارِ الْقَسَمِ أَوِ الْمُقْسِمِ وَنَصْرِ الْمَظْلُومِ وَإِجَابَةِ الدَّاعِي وَإِفْشَاءِ السَّلاَمِ ‏.‏ وَنَهَانَا عَنْ خَوَاتِيمَ أَوْ عَنْ تَخَتُّمٍ بِالذَّهَبِ وَعَنْ شُرْبٍ بِالْفِضَّةِ وَعَنِ الْمَيَاثِرِ وَعَنِ الْقَسِّيِّ وَعَنْ لُبْسِ الْحَرِيرِ وَالإِسْتَبْرَقِ وَالدِّيبَاجِ ‏.‏\hadithno{5388}\hadithtrans{Mu'awiya b. Suwaid b. Muqarrin reporxed:I visited al-Bara' b. 'Azib and heard him say: Allah's Messenger (ﷺ) commanded us to do seven things and forbade us to do seven (things). He commanded us to visit the sick, to follow the funeral procession, to answer the sneezer, to fulfil the vow, to help the poor, to accept the invitation and to greet everybody, and he forbade us to wear rings or gold rings, to drink in silver (vessels), and to use the saddle cloth made of red silk, and to wear garments made of Qassi material, or garments made of silk or brocade and velvet}}
\hadithdefcmd{muslim}{5389}{حَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَشْعَثَ بْنِ سُلَيْمٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ إِلاَّ قَوْلَهُ وَإِبْرَارِ الْقَسَمِ أَوِ الْمُقْسِمِ ‏.‏ فَإِنَّهُ لَمْ يَذْكُرْ هَذَا الْحَرْفَ فِي الْحَدِيثِ وَجَعَلَ مَكَانَهُ وَإِنْشَادِ الضَّالِّ ‏.‏\hadithno{5389}\hadithtrans{This hadith has been reported on the authority of Ash'ath b. Sulaim with the same chain of transmitters but with a slight change of wording that he made no mention of:" to fulfil the vows" but substituted these words:" finding of the lost articles}}
\hadithdefcmd{muslim}{5390}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي، شَيْبَةَ حَدَّثَنَا جَرِيرٌ، كِلاَهُمَا عَنِ الشَّيْبَانِيِّ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ زُهَيْرٍ وَقَالَ إِبْرَارِ الْقَسَمِ مِنْ غَيْرِ شَكٍّ وَزَادَ فِي الْحَدِيثِ وَعَنِ الشُّرْبِ فِي الْفِضَّةِ فَإِنَّهُ مَنْ شَرِبَ فِيهَا فِي الدُّنْيَا لَمْ يَشْرَبْ فِيهَا فِي الآخِرَةِ ‏.‏\hadithno{5390}\hadithtrans{This hadith has been narrated on the authority of Ash'ath b. Abu ashSha'tha' with the same chain of transmitters (and with these words):There is no doubt about the words: To fulfil the vows were mentioned and this addition had been made in the. hadith: (The Holy Prophet) forbade drinking in silver vessels, for one who drinks (in them) in this world would not drink (in them) in the Hereafter}}
\hadithdefcmd{muslim}{5391}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ إِدْرِيسَ، أَخْبَرَنَا أَبُو إِسْحَاقَ الشَّيْبَانِيُّ، وَلَيْثُ بْنُ، أَبِي سُلَيْمٍ عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، بِإِسْنَادِهِمْ وَلَمْ يَذْكُرْ زِيَادَةَ جَرِيرٍ وَابْنِ مُسْهِرٍ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ، مُعَاذٍ حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، ح وَحَدَّثَنَا عَبْدُ، الرَّحْمَنِ بْنُ بِشْرٍ حَدَّثَنَا بَهْزٌ، قَالُوا جَمِيعًا حَدَّثَنَا شُعْبَةُ، عَنْ أَشْعَثَ بْنِ سُلَيْمٍ، بِإِسْنَادِهِمْ وَمَعْنَى حَدِيثِهِمْ إِلاَّ قَوْلَهُ وَإِفْشَاءِ السَّلاَمِ ‏.‏ فَإِنَّهُ قَالَ بَدَلَهَا وَرَدِّ السَّلاَمِ ‏.‏ وَقَالَ نَهَانَا عَنْ خَاتَمِ الذَّهَبِ أَوْ حَلْقَةِ الذَّهَبِ ‏.‏\hadithno{5391}\hadithtrans{This hadith has been narrated on the authority of Ash'ath b. Sulaim with the same chain of transmitters but with this difference that instead of the words:Ifsha as-Salam (spreading the salutations), he substituted the words Radd as-Saldm (i. e. responding to the words of salutation) and he said: He forbade (the use of) gold ring}}
\hadithdefcmd{muslim}{5392}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، وَعَمْرُو بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، بِإِسْنَادِهِمْ وَقَالَ وَإِفْشَاءِ السَّلاَمِ وَخَاتَمِ الذَّهَبِ ‏.‏ مِنْ غَيْرِ شَكٍّ ‏.‏\hadithno{5392}\hadithtrans{This hadith has been narrated on the auttiniity of Ash'ath b. Sulaim with the same chain of transmitters but the words (pertaining to) Ifsha as-Salam and the (use) of gold ring have been reported without doubt}}
\hadithdefcmd{muslim}{5394}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرِو بْنِ سَهْلِ بْنِ إِسْحَاقَ بْنِ مُحَمَّدِ بْنِ الأَشْعَثِ بْنِ قَيْسٍ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، سَمِعْتُهُ يَذْكُرُهُ، عَنْ أَبِي فَرْوَةَ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُكَيْمٍ، قَالَ كُنَّا مَعَ حُذَيْفَةَ بِالْمَدَائِنِ فَاسْتَسْقَى حُذَيْفَةُ فَجَاءَهُ دِهْقَانٌ بِشَرَابٍ فِي إِنَاءٍ مِنْ فِضَّةٍ فَرَمَاهُ بِهِ وَقَالَ إِنِّي أُخْبِرُكُمْ أَنِّي قَدْ أَمَرْتُهُ أَنْ لاَ يَسْقِيَنِي فِيهِ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَشْرَبُوا فِي إِنَاءِ الذَّهَبِ وَالْفِضَّةِ وَلاَ تَلْبَسُوا الدِّيبَاجَ وَالْحَرِيرَ فَإِنَّهُ لَهُمْ فِي الدُّنْيَا وَهُوَ لَكُمْ فِي الآخِرَةِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5394}\hadithtrans{Abdullah b. Ukaim reported:While we were with Hudhaifa in Mada'in he asked for water. A villager brought a drink for him in a silver vessel. He (Hudhaifa) threw it away saying: I inform you that I have already conveyed to him that he should not serve me drink in it (silver vessel) for Allah's Messenger (ﷺ) had said: Do not drink in gold and silver vessels, and do not wear brocade or silk, for these are meant for them (the non-believers) in this world, but they are meant for you in the Hereafter on the Day, of Resurrection}}
\hadithdefcmd{muslim}{5395}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي فَرْوَةَ الْجُهَنِيِّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُكَيْمٍ يَقُولُ كُنَّا عِنْدَ حُذَيْفَةَ بِالْمَدَائِنِ ‏.‏ فَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرْ فِي الْحَدِيثِ ‏ "‏ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5395}\hadithtrans{This hadith has been reported on the authority of `Abdullah b. `Ukaim with a slight variation of wording}}
\hadithdefcmd{muslim}{5396}{وَحَدَّثَنِي عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ أَبِي نَجِيحٍ، أَوَّلاً عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ حُذَيْفَةَ، ثُمَّ حَدَّثَنَا يَزِيدُ، سَمِعَهُ مِنِ ابْنِ أَبِي لَيْلَى، عَنْ حُذَيْفَةَ، ثُمَّ حَدَّثَنَا أَبُو فَرْوَةَ، قَالَ سَمِعْتُ ابْنَ عُكَيْمٍ، فَظَنَنْتُ أَنَّ ابْنَ أَبِي لَيْلَى، إِنَّمَا سَمِعَهُ مِنِ ابْنِ، عُكَيْمٍ قَالَ كُنَّا مَعَ حُذَيْفَةَ بِالْمَدَائِنِ ‏.‏ فَذَكَرَ نَحْوَهُ وَلَمْ يَقُلْ ‏ "‏ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5396}\hadithtrans{This hadith has been narrated on the authority of lbn `Ukaim through another chain of transmitters, but in this hadith no mention is made of the words:"On the Day of Resurrection}}
\hadithdefcmd{muslim}{5397}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ، - يَعْنِي ابْنَ أَبِي لَيْلَى - قَالَ شَهِدْتُ حُذَيْفَةَ اسْتَسْقَى بِالْمَدَائِنِ فَأَتَاهُ إِنْسَانٌ بِإِنَاءٍ مِنْ فِضَّةٍ ‏.‏ فَذَكَرَهُ بِمَعْنَى حَدِيثِ ابْنِ عُكَيْمٍ عَنْ حُذَيْفَةَ ‏.‏\hadithno{5397}\hadithtrans{Shu'ba reported from al-Hakam that he heard 'Abd al-Rahmin (i. e. Ibn Abu Laila) as saying:I personally saw Hudhaifa asking for water in Mada'in and a man giving it to him in a silver vessel. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5398}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، حَدَّثَنَا بَهْزٌ، كُلُّهُمْ عَنْ شُعْبَةَ، ‏.‏ بِمِثْلِ حَدِيثِ مُعَاذٍ وَإِسْنَادِهِ وَلَمْ يَذْكُرْ أَحَدٌ مِنْهُمْ فِي الْحَدِيثِ شَهِدْتُ حُذَيْفَةَ ‏.‏ غَيْرُ مُعَاذٍ وَحْدَهُ إِنَّمَا قَالُوا إِنَّ حُذَيْفَةَ اسْتَسْقَى.‏\hadithno{5398}\hadithtrans{This hadith has been narrated on the authority of Shu`ba through another chain of transmitters. But there is no mention of "I personally saw him" in this hadith}}
\hadithdefcmd{muslim}{5399}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، كِلاَهُمَا عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ مَنْ ذَكَرْنَا ‏.‏\hadithno{5399}\hadithtrans{This hadith has been reported on the authority of Hudhaila with the same chain of transmitters}}
\hadithdefcmd{muslim}{5400}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سَيْفٌ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، قَالَ اسْتَسْقَى حُذَيْفَةُ فَسَقَاهُ مَجُوسِيٌّ فِي إِنَاءٍ مِنْ فِضَّةٍ فَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَلْبَسُوا الْحَرِيرَ وَلاَ الدِّيبَاجَ وَلاَ تَشْرَبُوا فِي آنِيَةِ الذَّهَبِ وَالْفِضَّةِ وَلاَ تَأْكُلُوا فِي صِحَافِهَا فَإِنَّهَا لَهُمْ فِي الدُّنْيَا‏"‏ ‏.‏\hadithno{5400}\hadithtrans{Abd al-Rahmin b. Abu Laili reported that Hudhaifa asked for water and a Magian gave him water in a silver vessel, whereupon he said:I heard Allah's Messenger (ﷺ) as saying: Do not wear silk or brocade and do not drink ifi vessels of gold and silver, and do not eat in the dishes made of them (i. e. gold and silver), for these are for them (the non-believers) in this world}}
\hadithdefcmd{muslim}{5401}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، بْنَ الْخَطَّابِ رَأَى حُلَّةً سِيَرَاءَ عِنْدَ بَابِ الْمَسْجِدِ فَقَالَ يَا رَسُولَ اللَّهِ لَوِ اشْتَرَيْتَ هَذِهِ فَلَبِسْتَهَا لِلنَّاسِ يَوْمَ الْجُمُعَةِ وَلِلْوَفْدِ إِذَا قَدِمُوا عَلَيْكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏ ‏.‏ ثُمَّ جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْهَا حُلَلٌ فَأَعْطَى عُمَرَ مِنْهَا حُلَّةً فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ كَسَوْتَنِيهَا وَقَدْ قُلْتَ فِي حُلَّةِ عُطَارِدٍ مَا قُلْتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لَمْ أَكْسُكَهَا لِتَلْبَسَهَا ‏"‏ ‏.‏ فَكَسَاهَا عُمَرُ أَخًا لَهُ مُشْرِكًا بِمَكَّةَ ‏.‏\hadithno{5401}\hadithtrans{Ibn Umar reported that Umar b. Khattab saw (some one selling) the garments of silk at the door of the mosque, whereupon he said:Allah's Messenger, would that you buy it and wear it for the people on Friday and for (receiving) the delegations when they come to you? Upon this. Allah's Messenger (ﷺ) said: go who wears it has no share (of reward) in the Hereafter. Then these garments were sent to Allah" s Messenger (ﷺ), and he presented one of these silk garment to Umar. Thereupon Umar said: You make me wear (this silk garment) Whereas you said about the silk garment of Utarid (the person who had been busy selling this garment at the door of the mosque) what you had to say, whereupon Allah's Messenger (ﷺ) said: I have not presented you this for wearing it (but to make use of its price) ; so 'Umar presented it to his polytheist brother in Mecca}}
\hadithdefcmd{muslim}{5402}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، كِلاَهُمَا عَنْ نَافِعٍ، عَنِ ابْنِ، عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ حَدِيثِ مَالِكٍ ‏.‏\hadithno{5402}\hadithtrans{This hadith has been narrated by Ibn Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{5403}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَى عُمَرُ عُطَارِدًا التَّمِيمِيَّ يُقِيمُ بِالسُّوقِ حُلَّةً سِيَرَاءَ - وَكَانَ رَجُلاً يَغْشَى الْمُلُوكَ وَيُصِيبُ مِنْهُمْ - فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ إِنِّي رَأَيْتُ عُطَارِدًا يُقِيمُ فِي السُّوقِ حُلَّةً سِيَرَاءَ فَلَوِ اشْتَرَيْتَهَا فَلَبِسْتَهَا لِوُفُودِ الْعَرَبِ إِذَا قَدِمُوا عَلَيْكَ - وَأَظُنُّهُ قَالَ وَلَبِسْتَهَا يَوْمَ الْجُمُعَةِ - فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا يَلْبَسُ الْحَرِيرَ فِي الدُّنْيَا مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏ ‏.‏ فَلَمَّا كَانَ بَعْدَ ذَلِكَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِحُلَلٍ سِيَرَاءَ فَبَعَثَ إِلَى عُمَرَ بِحُلَّةٍ وَبَعَثَ إِلَى أُسَامَةَ بْنِ زَيْدٍ بِحُلَّةٍ وَأَعْطَى عَلِيَّ بْنَ أَبِي طَالِبٍ حُلَّةً وَقَالَ ‏"‏ شَقِّقْهَا خُمُرًا بَيْنَ نِسَائِكَ ‏"‏ ‏.‏ قَالَ فَجَاءَ عُمَرُ بِحُلَّتِهِ يَحْمِلُهَا فَقَالَ يَا رَسُولَ اللَّهِ بَعَثْتَ إِلَىَّ بِهَذِهِ وَقَدْ قُلْتَ بِالأَمْسِ فِي حُلَّةِ عُطَارِدٍ مَا قُلْتَ فَقَالَ ‏"‏ إِنِّي لَمْ أَبْعَثْ بِهَا إِلَيْكَ لِتَلْبَسَهَا وَلَكِنِّي بَعَثْتُ بِهَا إِلَيْكَ لِتُصِيبَ بِهَا ‏"‏ ‏.‏ وَأَمَّا أُسَامَةُ فَرَاحَ فِي حُلَّتِهِ فَنَظَرَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم نَظَرًا عَرَفَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَنْكَرَ مَا صَنَعَ فَقَالَ يَا رَسُولَ اللَّهِ مَا تَنْظُرُ إِلَىَّ فَأَنْتَ بَعَثْتَ إِلَىَّ بِهَا فَقَالَ ‏"‏ إِنِّي لَمْ أَبْعَثْ إِلَيْكَ لِتَلْبَسَهَا وَلَكِنِّي بَعَثْتُ بِهَا إِلَيْكَ لِتُشَقِّقَهَا خُمُرًا بَيْنَ نِسَائِكَ ‏"‏ ‏.‏\hadithno{5403}\hadithtrans{Ibn Umar reported that Umar saw Utarid al-Tamimi standing in the market (and selling) the silk garments, and he was the person who went to (courts of) kings and got (high prices) for these garments from them. Umar said:Allah's Messenger I saw 'Utarid standing in the market with a silk garment; would that you buy and wear it for (receiving) the delegations of Arabs when they visit you? I (the narrator) said: I think he ('Umar) also said: You may wear it on Friday (also). Thereupon, Allah's Messenger (may peace he upon him) said: He who wears silk in this world has no share in the Hereafter. Later on when these silk garments were presented to Allah's Massenger (ﷺ) he presented one silk garment to 'Umar and presented one also to Usama b. Zaid and gave one to 'Ali b. Abu 'Talib. saying: Tear them and make head coverings for your ladies. 'Umar came carrying his garment and said: Allah's Messenger, you have sent it to me, whereas you had said yesterday about the (silk) garment of Utarid what you had to say. He (the Holy Prophet) said: I have not sent it to you that you wear it, but I have sent It to you so that you may derive benefit out of it; and Usama (donned) the garment (presented to him) and appeared to be brisk, whereupon Allah's Apostle (ﷺ) looked at him with a look by which he perceived that the Messenger of Allah (ﷺ) did not like what he had done. He said: Allah's Messenger. why is it that you look at me like this. whereas you yourself presented it to me? He said: I never sent it to you to wear it, but I sent It to you so that you may tear it and make out head covering for your ladies}}
\hadithdefcmd{muslim}{5404}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لِحَرْمَلَةَ - قَالاَ أَخْبَرَنَا ابْنُ، وَهْبٍ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ وَجَدَ عُمَرُ بْنُ الْخَطَّابِ حُلَّةً مِنْ إِسْتَبْرَقٍ تُبَاعُ بِالسُّوقِ فَأَخَذَهَا فَأَتَى بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ ابْتَعْ هَذِهِ فَتَجَمَّلْ بِهَا لِلْعِيدِ وَلِلْوَفْدِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا هَذِهِ لِبَاسُ مَنْ لاَ خَلاَقَ لَهُ ‏"‏ ‏.‏ قَالَ فَلَبِثَ عُمَرُ مَا شَاءَ اللَّهُ .‏ ثُمَّ أَرْسَلَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِجُبَّةِ دِيبَاجٍ فَأَقْبَلَ بِهَا عُمَرُ حَتَّى أَتَى بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ قُلْتَ ‏"‏ إِنَّمَا هَذِهِ لِبَاسُ مَنْ لاَ خَلاَقَ لَهُ ‏"‏ ‏.‏ أَوْ ‏"‏ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ ‏"‏ ‏.‏ ثُمَّ أَرْسَلْتَ إِلَىَّ بِهَذِهِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَبِيعُهَا وَتُصِيبُ بِهَا حَاجَتَكَ ‏"‏ ‏.‏\hadithno{5404}\hadithtrans{Abdullah b. Umar reported:'Umar b. at-Khattab found a silk garment being sold in the market; he purchased it and brought it to Allah's Messenger (ﷺ) and said: Allah's Messenger, get it and adorn yourself (by wearing it) on the 'Id (days) and for the delegation. Thereupon, Allah's Messenger (ﷺ) said: That is the dress of one who has no share (in the Hereafter). 'Umar stayed there so long as Allah wished. Then Allah's Messenger (ﷺ) sent him a silk cloak. 'Umar came back with that to Allah's Messenger (ﷺ) and said: Allah's Messenger. you said that it is the dress of one who has no share in the Hereafter, but then you sent it to me. Thereupon, Allah's Messenger (ﷺ) said: You sell it and meet your need (with its proceeds)}}
\hadithdefcmd{muslim}{5405}{وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5405}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters}}
\hadithdefcmd{muslim}{5406}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، أَخْبَرَنِي أَبُو بَكْرِ بْنُ، حَفْصٍ عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، رَأَى عَلَى رَجُلٍ مِنْ آلِ عُطَارِدٍ قَبَاءً مِنْ دِيبَاجٍ أَوْ حَرِيرٍ فَقَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم لَوِ اشْتَرَيْتَهُ ‏.‏ فَقَالَ ‏"‏ إِنَّمَا يَلْبَسُ هَذَا مَنْ لاَ خَلاَقَ لَهُ ‏"‏ ‏.‏ فَأُهْدِيَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حُلَّةٌ سِيَرَاءُ فَأَرْسَلَ بِهَا إِلَىَّ ‏.‏ قَالَ قُلْتُ أَرْسَلْتَ بِهَا إِلَىَّ وَقَدْ سَمِعْتُكَ قُلْتَ فِيهَا مَا قُلْتَ قَالَ ‏"‏ إِنَّمَا بَعَثْتُ بِهَا إِلَيْكَ لِتَسْتَمْتِعَ بِهَا ‏"‏ ‏.‏\hadithno{5406}\hadithtrans{lbn 'Umar reported that 'Umar saw a person of the tribe of 'Utirid selling a garment made of brocade or silk and said to Allah's Messenger (ﷺ):Would that you buy it? Thereupon he (the Holy Prophet) said: He who wears it has no share for him in the Hereafter. Then Allah's Messenger (ﷺ) was presented with a striped silk garment and he sent it to him ('Umar). He (, Umar) said: You sent it to me whereas I heard from you about it what you had to say, whereupon he (Allah's Messenger) said: I sent it to you so that you may benefit by it}}
\hadithdefcmd{muslim}{5407}{وَحَدَّثَنِي ابْنُ نُمَيْرٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو بَكْرِ بْنُ حَفْصٍ، عَنْ سَالِمِ، بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رَأَى عَلَى رَجُلٍ مِنْ آلِ عُطَارِدٍ ‏.‏ بِمِثْلِ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ غَيْرَ أَنَّهُ قَالَ ‏ "‏ إِنَّمَا بَعَثْتُ بِهَا إِلَيْكَ لِتَنْتَفِعَ بِهَا وَلَمْ أَبْعَثْ بِهَا إِلَيْكَ لِتَلْبَسَهَا ‏"‏ ‏.‏\hadithno{5407}\hadithtrans{This hadith has been narrated on the authority of Ibn Umar through another chain of transmitters but with a slight variation of wording (and the words are that the Holy Prophet) said:I sent it to you so that you might derive benefit from it. but I did not send it to you to wear it}}
\hadithdefcmd{muslim}{5408}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي إِسْحَاقَ، قَالَ قَالَ لِي سَالِمُ بْنُ عَبْدِ اللَّهِ فِي الإِسْتَبْرَقِ قَالَ قُلْتُ مَا غَلُظَ مِنَ الدِّيبَاجِ وَخَشُنَ مِنْهُ ‏.‏ فَقَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَقُولُ رَأَى عُمَرُ عَلَى رَجُلٍ حُلَّةً مِنْ إِسْتَبْرَقٍ فَأَتَى بِهَا النَّبِيَّ صلى الله عليه وسلم ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِهِمْ غَيْرَ أَنَّهُ قَالَ فَقَالَ ‏ "‏ إِنَّمَا بَعَثْتُ بِهَا إِلَيْكَ لِتُصِيبَ بِهَا مَالاً ‏"‏ ‏.‏\hadithno{5408}\hadithtrans{Ibn 'Umar reported that 'Umar saw a person with a garment of brocade and he brought it to Allah's Apostle (may peace he upon him) -the rest of the hadith is the same, except for the words that he (the Holy Prophet) said:I sent it to you that you might get money thereby}}
\hadithdefcmd{muslim}{5409}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَبْدِ اللَّهِ، مَوْلَى أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ وَكَانَ خَالَ وَلَدِ عَطَاءٍ قَالَ أَرْسَلَتْنِي أَسْمَاءُ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ فَقَالَتْ بَلَغَنِي أَنَّكَ تُحَرِّمُ أَشْيَاءَ ثَلاَثَةً الْعَلَمَ فِي الثَّوْبِ وَمِيثَرَةَ الأُرْجُوَانِ وَصَوْمَ رَجَبٍ كُلِّهِ ‏.‏ فَقَالَ لِي عَبْدُ اللَّهِ أَمَّا مَا ذَكَرْتَ مِنْ رَجَبٍ فَكَيْفَ بِمَنْ يَصُومُ الأَبَدَ وَأَمَّا مَا ذَكَرْتَ مِنَ الْعَلَمِ فِي الثَّوْبِ فَإِنِّي سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا يَلْبَسُ الْحَرِيرَ مَنْ لاَ خَلاَقَ لَهُ ‏"‏ ‏.‏ فَخِفْتُ أَنْ يَكُونَ الْعَلَمُ مِنْهُ وَأَمَّا مِيثَرَةُ الأُرْجُوَانِ فَهَذِهِ مِيثَرَةُ عَبْدِ اللَّهِ فَإِذَا هِيَ أُرْجُوَانٌ ‏.‏ فَرَجَعْتُ إِلَى أَسْمَاءَ فَخَبَّرْتُهَا فَقَالَتْ هَذِهِ جُبَّةُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَخْرَجَتْ إِلَىَّ جُبَّةَ طَيَالَسَةٍ كِسْرَوَانِيَّةً لَهَا لِبْنَةُ دِيبَاجٍ وَفَرْجَيْهَا مَكْفُوفَيْنِ بِالدِّيبَاجِ فَقَالَتْ هَذِهِ كَانَتْ عِنْدَ عَائِشَةَ حَتَّى قُبِضَتْ فَلَمَّا قُبِضَتْ قَبَضْتُهَا وَكَانَ النَّبِيُّ صلى الله عليه وسلم يَلْبَسُهَا فَنَحْنُ نَغْسِلُهَا لِلْمَرْضَى يُسْتَشْفَى بِهَا ‏.‏\hadithno{5409}\hadithtrans{Abdullah. the freed slave of Asma' (the daughter of Abu Bakr). the maternal uncle of the son of 'Ata, reported:Asma' sent me to 'Abdullah b. 'Umar saying: The news has reached me that you prohibit the use of three things: the striped robe. saddle cloth made of red silk. and the fasting in the holy month of Rajab. 'Abdullah said to me: So far as what you say about fasting in the month of Rajab, how about one who observes continuous fasting? -and so far as what you say about the striped garment, I heard Umar b. Khatab say that he had heard from Allah's Messenger (ﷺ): He who wears silk garment has no share for him (in the Hereafter), and I am afraid it may not be that striped garment; and so far as the red saddle clotb is concerned that is the saddle cloth of Abdullah and it is red. I went back to Asma' and informed her. whereupon she said: Here is the cloak of Allah's Messenger (ﷺ). and she brought out to me that cloak made of Persian cloth with a hem of brocade, and its sleeves bordered with brocade and said: This wall Allah's Messenger's cloak with 'A'isha until she died, and when she died. I got possession of it. The Apostle of Allah (ﷺ) used to wear that, and we waslied it for the sick and sought cure thereby}}
\hadithdefcmd{muslim}{5410}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ خَلِيفَةَ بْنِ كَعْبٍ، أَبِي ذُبْيَانَ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، يَخْطُبُ يَقُولُ أَلاَ لاَ تُلْبِسُوا نِسَاءَكُمُ الْحَرِيرَ فَإِنِّي سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلْبَسُوا الْحَرِيرَ فَإِنَّهُ مَنْ لَبِسَهُ فِي الدُّنْيَا لَمْ يَلْبَسْهُ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5410}\hadithtrans{Khalifa b. Ka'b AbCi Dhubyan reported:I heard 'Abdullah b. Zubair addressing the people and saying: Behold! do not dress yuor women with silk clothes for I heard 'Umar b. Khattab as sayinp that he had heard Allah's messenger (ﷺ) as saying: Do not wear silk, for one who wear it in this world will not wear it in the Hereafter}}
\hadithdefcmd{muslim}{5411}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَبِي، عُثْمَانَ قَالَ كَتَبَ إِلَيْنَا عُمَرُ وَنَحْنُ بِأَذْرَبِيجَانَ يَا عُتْبَةَ بْنَ فَرْقَدٍ إِنَّهُ لَيْسَ مِنْ كَدِّكَ وَلاَ مِنْ كَدِّ أَبِيكَ وَلاَ مِنْ كَدِّ أُمِّكَ فَأَشْبِعِ الْمُسْلِمِينَ فِي رِحَالِهِمْ مِمَّا تَشْبَعُ مِنْهُ فِي رَحْلِكَ وَإِيَّاكُمْ وَالتَّنَعُّمَ وَزِيَّ أَهْلِ الشِّرْكِ وَلَبُوسَ الْحَرِيرِ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لَبُوسِ الْحَرِيرِ ‏.‏ قَالَ ‏ "‏ إِلاَّ هَكَذَا ‏"‏ ‏.‏ وَرَفَعَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم إِصْبَعَيْهِ الْوُسْطَى وَالسَّبَّابَةَ وَضَمَّهُمَا قَالَ زُهَيْرٌ قَالَ عَاصِمٌ هَذَا فِي الْكِتَابِ ‏.‏ قَالَ وَرَفَعَ زُهَيْرٌ إِصْبَعَيْهِ ‏.‏\hadithno{5411}\hadithtrans{Asim al-Abwal reported on the authority Abu Uthman saying:'Umar wrote to us when we were in Adharba'ijan saying: 'Utba b. Farqad, this wealth is neither the result of your own labour nor the result of the labour of your father, nor the result of the labour of your mother, so feed Muslims at their own places as you feed (members of your family and yourselves at your own residence), and beware of the life of pleasure, and the dress of the polytheists and wearing of silk garments, for Allah's Messenger (ﷺ) forbade the wearing of silk garments, but only this much, and Allah's Messenger (ﷺ) raised his. forefinger and middle finger and he joined. them (to indicate that only this much silk can be allowed in the dress of a man). 'Asim said also: This is what is recorded in the lette., (sent to us), and Zuhair raised his two fingers (to give an idea of the extent to which silk may be used)}}
\hadithdefcmd{muslim}{5412}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدُ الْحَمِيدِ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، كِلاَهُمَا عَنْ عَاصِمٍ، بِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْحَرِيرِ‏ بِمِثْلِهِ ‏.‏\hadithno{5412}\hadithtrans{This hadith has been transmitted on the authority of 'Asim}}
\hadithdefcmd{muslim}{5413}{وَحَدَّثَنَا ابْنُ أَبِي شَيْبَةَ، - وَهُوَ عُثْمَانُ - وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ كِلاَهُمَا عَنْ جَرِيرٍ، - وَاللَّفْظُ لإِسْحَاقَ - أَخْبَرَنَا جَرِيرٌ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، قَالَ كُنَّا مَعَ عُتْبَةَ بْنِ فَرْقَدٍ فَجَاءَنَا كِتَابُ عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَلْبَسُ الْحَرِيرَ إِلاَّ مَنْ لَيْسَ لَهُ مِنْهُ شَىْءٌ فِي الآخِرَةِ إِلاَّ هَكَذَا ‏"‏ ‏.‏ وَقَالَ أَبُو عُثْمَانَ بِإِصْبَعَيْهِ اللَّتَيْنِ تَلِيَانِ الإِبْهَامَ ‏.‏ فَرُئِيتُهُمَا أَزْرَارَ الطَّيَالِسَةِ حِينَ رَأَيْتُ الطَّيَالِسَةَ ‏.‏\hadithno{5413}\hadithtrans{Abu 'Uthman reported:While we were with 'Utba b. Farqad there came a letter of 'Umar (containing the instructions) that Allah's Messenger (ﷺ) had said: None should wear silk (with the exception of so much) but he will have nothing of it in the Hereafter. Abu 'Uthman said: To the extent of two fingers which are close to the thumb, and I was shown the (silk) borders of the Tayalisa mantle (which were about two fingers in breadth and I saw them)}}
\hadithdefcmd{muslim}{5414}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، حَدَّثَنَا أَبُو عُثْمَانَ، قَالَ كُنَّا مَعَ عُتْبَةَ بْنِ فَرْقَدٍ بِمِثْلِ حَدِيثِ جَرِيرٍ ‏.‏\hadithno{5414}\hadithtrans{The previous hadith is narrated likewise through another chain of transmitters}}
\hadithdefcmd{muslim}{5415}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا عُثْمَانَ النَّهْدِيَّ، قَالَ جَاءَنَا كِتَابُ عُمَرَ وَنَحْنُ بِأَذْرَبِيجَانَ مَعَ عُتْبَةَ بْنِ فَرْقَدٍ أَوْ بِالشَّامِ أَمَّا بَعْدُ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْحَرِيرِ إِلاَّ هَكَذَا إِصْبَعَيْنِ ‏.‏ قَالَ أَبُو عُثْمَانَ فَمَا عَتَّمْنَا أَنَّهُ يَعْنِي الأَعْلاَمَ‏.‏\hadithno{5415}\hadithtrans{Qatada reported:I heard Abe 'Uthman al-Nahdi as saying: There came to us a letter of 'Umar as we were in Adharba'ijan or in Syria in the company of 'Utba b. Farqad (and the letter ran thus): After (usual praise and glorification of Allah) it is stated that Allah's Messenger (ﷺ) has forbidden the use of silk btit to the extent of these two fingers, and Abu Uthman said: We at once understood by these words that he meant (silk) patterns on (the cloth)}}
\hadithdefcmd{muslim}{5416}{وَحَدَّثَنَا أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُعَاذٌ، - وَهُوَ ابْنُ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَلَمْ يَذْكُرْ قَوْلَ أَبِي عُثْمَانَ ‏.‏\hadithno{5416}\hadithtrans{This hadith has been reported on the authority of Qatada but there is no mention of the words of Abd Uthman}}
\hadithdefcmd{muslim}{5417}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَأَبُو غَسَّانَ الْمِسْمَعِيُّ وَزُهَيْرُ بْنُ حَرْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ وَمُحَمَّدُ بْنُ الْمُثَنَّى وَابْنُ بَشَّارٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا - مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، أَنَّ عُمَرَ، بْنَ الْخَطَّابَ خَطَبَ بِالْجَابِيَةِ فَقَالَ نَهَى نَبِيُّ اللَّهِ صلى الله عليه وسلم عَنْ لُبْسِ الْحَرِيرِ إِلاَّ مَوْضِعَ إِصْبَعَيْنِ أَوْ ثَلاَثٍ أَوْ أَرْبَعٍ ‏.‏\hadithno{5417}\hadithtrans{Suwaid b. Ghafala said:'Umar addressed us at a place known as Jabiya (Syria) and he said: Allah's Apostle (ﷺ) forbade us the wearing of silk but to the extent of two or three fingers or four fingers}}
\hadithdefcmd{muslim}{5418}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرُّزِّيُّ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5418}\hadithtrans{This hadith has been narrated on the authority of Qatada with the same chain of transmitters}}
\hadithdefcmd{muslim}{5419}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَيَحْيَى بْنُ حَبِيبٍ، وَحَجَّاجُ بْنُ الشَّاعِرِ - وَاللَّفْظُ لاِبْنِ حَبِيبٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ لَبِسَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا قَبَاءً مِنْ دِيبَاجٍ أُهْدِيَ لَهُ ثُمَّ أَوْشَكَ أَنْ نَزَعَهُ فَأَرْسَلَ بِهِ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقِيلَ لَهُ قَدْ أَوْشَكَ مَا نَزَعْتَهُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ نَهَانِي عَنْهُ جِبْرِيلُ ‏"‏ ‏.‏ فَجَاءَهُ عُمَرُ يَبْكِي فَقَالَ يَا رَسُولَ اللَّهِ كَرِهْتَ أَمْرًا وَأَعْطَيْتَنِيهِ فَمَا لِي قَالَ ‏"‏ إِنِّي لَمْ أُعْطِكَهُ لِتَلْبَسَهُ إِنَّمَا أَعْطَيْتُكَهُ تَبِيعُهُ ‏"‏ ‏.‏ فَبَاعَهُ بِأَلْفَىْ دِرْهَمٍ ‏.‏\hadithno{5419}\hadithtrans{Jabir b. Abdullah reported that one day Allah's Apostle (ﷺ) put on a cloak made of brocade, which had been presented to him. He then quickly put it off and sent it to 'Umar b. Khattab, and it was said to him:Messenger of Allah. why is it that you put it of immediately. whereupon he said: Gabriel forbade me from it (i. e. wearing of Ods garment), and 'Umar came to him weeping and said: Messenger of Allah you disapproved a thing but you gave it to me. What about me, then? Thereupon be (the Holy Prophet) Wd: I did not give it to you to wear it, but I gave you that you might sell it; and so he (Hadrat Umar) sold it for two thousand dirhams}}
\hadithdefcmd{muslim}{5420}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عَوْنٍ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، يُحَدِّثُ عَنْ عَلِيٍّ، قَالَ أُهْدِيَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم حُلَّةُ سِيَرَاءَ فَبَعَثَ بِهَا إِلَىَّ فَلَبِسْتُهَا فَعَرَفْتُ الْغَضَبَ فِي وَجْهِهِ فَقَالَ ‏ "‏ إِنِّي لَمْ أَبْعَثْ بِهَا إِلَيْكَ لِتَلْبَسَهَا إِنَّمَا بَعَثْتُ بِهَا إِلَيْكَ لِتُشَقِّقَهَا خُمُرًا بَيْنَ النِّسَاءِ ‏"‏ ‏.‏\hadithno{5420}\hadithtrans{Ali reported:A silk cloak was presented to Allah's Messenger (ﷺ). and he sent it to me and I wore it. but then found some sign of disapproval upon his face, whereupon he said: I did not send it to you that you wear it, but I sent it to you so that you might tear it and make out head dream for your women}}
\hadithdefcmd{muslim}{5421}{حَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عَوْنٍ، بِهَذَا الإِسْنَادِ فِي حَدِيثِ مُعَاذٍ فَأَمَرَنِي فَأَطَرْتُهَا بَيْنَ نِسَائِي ‏.‏ وَفِي حَدِيثِ مُحَمَّدِ بْنِ جَعْفَرٍ فَأَطَرْتُهَا بَيْنَ نِسَائِي ‏.‏ وَلَمْ يَذْكُرْ فَأَمَرَنِي‏.‏\hadithno{5421}\hadithtrans{This hadith has been narrated on the authority of Muhammad b. Ja'far but with a slight variation of wording}}
\hadithdefcmd{muslim}{5422}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَزُهَيْرُ بْنُ حَرْبٍ - وَاللَّفْظُ لِزُهَيْرٍ - قَالَ أَبُو كُرَيْبٍ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ أَبِي عَوْنٍ الثَّقَفِيِّ، عَنْ أَبِي صَالِحٍ الْحَنَفِيِّ، عَنْ عَلِيٍّ، أَنَّ أُكَيْدِرَ، دُومَةَ أَهْدَى إِلَى النَّبِيِّ صلى الله عليه وسلم ثَوْبَ حَرِيرٍ فَأَعْطَاهُ عَلِيًّا فَقَالَ ‏"‏ شَقِّقْهُ خُمُرًا بَيْنَ الْفَوَاطِمِ ‏"‏ ‏.‏ وَقَالَ أَبُو بَكْرٍ وَأَبُو كُرَيْبٍ ‏"‏ بَيْنَ النِّسْوَةِ ‏"‏ ‏.‏\hadithno{5422}\hadithtrans{Ali reported that Ukaidir of Duma presented to Allah's Apostle (ﷺ) a silk garment, and he presented it to 'Ali. and said:Tear it to make head covering for Fitimas out of it. This tradition is transmitted on the authority of Abu Bakr, and Abu Kuraib said: Among the women}}
\hadithdefcmd{muslim}{5423}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كَسَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم حُلَّةَ سِيَرَاءَ فَخَرَجْتُ فِيهَا فَرَأَيْتُ الْغَضَبَ فِي وَجْهِهِ - قَالَ - فَشَقَقْتُهَا بَيْنَ نِسَائِي ‏.‏\hadithno{5423}\hadithtrans{Ali b. Abu Talib reported that Allah's Messenger (ﷺ) gave me to wear a garment in the form of silk cloak. I went out wearing it, but saw signs of anger on his face, so I tore it and distributed it amongst my women}}
\hadithdefcmd{muslim}{5424}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، وَأَبُو كَامِلٍ - وَاللَّفْظُ لأَبِي كَامِلٍ - قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصَمِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى عُمَرَ بِجُبَّةِ سُنْدُسٍ فَقَالَ عُمَرُ بَعَثْتَ بِهَا إِلَىَّ وَقَدْ قُلْتَ فِيهَا مَا قُلْتَ قَالَ ‏ "‏ إِنِّي لَمْ أَبْعَثْ بِهَا إِلَيْكَ لِتَلْبَسَهَا وَإِنَّمَا بَعَثْتُ بِهَا إِلَيْكَ لِتَنْتَفِعَ بِثَمَنِهَا ‏"‏ ‏.‏\hadithno{5424}\hadithtrans{Anas b. Malik reported that Allah's Messenger (may Peace be upon him) sent a silk gown to 'Umar, whereupon 'Umar said:You sent it to me whereas you said what you had to, say (i. e. it is forbidden for men). Thereupon he (the Holy Prophet) said: I did not send it to you so that you might wear it, but I sent it to you so that you might derive benefit from its price}}
\hadithdefcmd{muslim}{5425}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَبِسَ الْحَرِيرَ فِي الدُّنْيَا لَمْ يَلْبَسْهُ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5425}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) said:He who wore silk in this world would not wear it in the Hereafter}}
\hadithdefcmd{muslim}{5426}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا شُعَيْبُ بْنُ إِسْحَاقَ الدِّمَشْقِيُّ، عَنِ الأَوْزَاعِيِّ، حَدَّثَنِي شَدَّادٌ أَبُو عَمَّارٍ، حَدَّثَنِي أَبُو أُمَامَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَبِسَ الْحَرِيرَ فِي الدُّنْيَا لَمْ يَلْبَسْهُ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{5426}\hadithtrans{Abu Umama reported Allah's Messenger (ﷺ) having said:He who wore silk in this world would not wear it in the Hereafter}}
\hadithdefcmd{muslim}{5427}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّهُ قَالَ أُهْدِيَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَرُّوجُ حَرِيرٍ فَلَبِسَهُ ثُمَّ صَلَّى فِيهِ ثُمَّ انْصَرَفَ فَنَزَعَهُ نَزْعًا شَدِيدًا كَالْكَارِهِ لَهُ ثُمَّ قَالَ ‏ "‏ لاَ يَنْبَغِي هَذَا لِلْمُتَّقِينَ ‏"‏.‏\hadithno{5427}\hadithtrans{Uqba b. 'Amir said:A silk go vn was presented to Allah's Messenger (ﷺ) and he wore it and observed prayer in it and then returned and put it off so violently as if he despised it. He then said: It does not befit the Godfearing persons}}
\hadithdefcmd{muslim}{5428}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا الضَّحَّاكُ، - يَعْنِي أَبَا عَاصِمٍ - حَدَّثَنَا عَبْدُ، الْحَمِيدِ بْنُ جَعْفَرٍ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5428}\hadithtrans{This hadith has been narrated on the authority of azid b. Abu Habib with the same chain of transmitters}}
\hadithdefcmd{muslim}{5429}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسَ بْنَ مَالِكٍ، أَنْبَأَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَالزُّبَيْرِ بْنِ الْعَوَّامِ فِي الْقُمُصِ الْحَرِيرِ فِي السَّفَرِ مِنْ حِكَّةٍ كَانَتْ بِهِمَا أَوْ وَجَعٍ كَانَ بِهِمَا ‏.‏\hadithno{5429}\hadithtrans{Anas b. Malik reported to them (his companions) that Allah's Messnger (ﷺ) had granted concession to Abd al-Rahman b. *Anf and Zubair b. 'Awwam for the wearing of a silk shirt during the journey and because of itch which they both had or any other disease from which both of them had been suffering}}
\hadithdefcmd{muslim}{5430}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا سَعِيدٌ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ فِي السَّفَرِ ‏.‏\hadithno{5430}\hadithtrans{This hadith has been narrated on the authority of Sa'd with the same chain of transmitters but there is no mention of the word" journey}}
\hadithdefcmd{muslim}{5431}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم - أَوْ رُخِّصَ - لِلزُّبَيْرِ بْنِ الْعَوَّامِ وَعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ فِي لُبْسِ الْحَرِيرِ لِحِكَّةٍ كَانَتْ بِهِمَا ‏.‏\hadithno{5431}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) granted concession, or Zubair b. Awwam and 'Abd Al-Rahman b. Auf were granted concession, for the wearing of silk because of the itch that they both had}}
\hadithdefcmd{muslim}{5432}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5432}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{5433}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسًا، أَخْبَرَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ وَالزُّبَيْرَ بْنَ الْعَوَّامِ شَكَوَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْقَمْلَ فَرَخَّصَ لَهُمَا فِي قُمُصِ الْحَرِيرِ فِي غَزَاةٍ لَهُمَا ‏.‏\hadithno{5433}\hadithtrans{Anas b. Malik reported that 'Abd al-Rahman b. Auf and Zu'bair. b. 'Awwam complained to Allah's Messenger (ﷺ) about lice; he granted them concession to wear shirts of silk}}
\hadithdefcmd{muslim}{5434}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يَحْيَى، حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ الْحَارِثِ، أَنَّ ابْنَ مَعْدَانَ، أَخْبَرَهُ أَنَّ جُبَيْرَ بْنَ نُفَيْرٍ أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ أَخْبَرَهُ قَالَ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَىَّ ثَوْبَيْنِ مُعَصْفَرَيْنِ فَقَالَ ‏ "‏ إِنَّ هَذِهِ مِنْ ثِيَابِ الْكُفَّارِ فَلاَ تَلْبَسْهَا ‏"‏ ‏.‏\hadithno{5434}\hadithtrans{Abdullah b. 'Amr b. al-As reported:Allah's Messenger (ﷺ) saw me wearing two clothes dyed in saffron. whereupon he said: These are the clothes (usually worn by) the non-believers, so do not wear them}}
\hadithdefcmd{muslim}{5435}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، كِلاَهُمَا عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، بِهَذَا الإِسْنَادِ وَقَالاَ عَنْ خَالِدِ بْنِ مَعْدَانَ، ‏.‏\hadithno{5435}\hadithtrans{This hadith has been reported on the authority of Yahya b. Abu Kathir with the same chain of trarnmitteis}}
\hadithdefcmd{muslim}{5436}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا عُمَرُ بْنُ أَيُّوبَ الْمَوْصِلِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ طَاوُسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ رَأَى النَّبِيُّ صلى الله عليه وسلم عَلَىَّ ثَوْبَيْنِ مُعَصْفَرَيْنِ فَقَالَ ‏"‏ أَأُمُّكَ أَمَرَتْكَ بِهَذَا ‏"‏ ‏.‏ قُلْتُ أَغْسِلُهُمَا ‏.‏ قَالَ ‏"‏ بَلْ أَحْرِقْهُمَا ‏"‏ ‏.‏\hadithno{5436}\hadithtrans{Abdullah b. 'Amr reported:Allah's Apostle (ﷺ) saw me in two clothes dyed in saffron, whereupon he said: Has your mother ordered you to do so? And I said: I will wash them. He said: But burn them}}
\hadithdefcmd{muslim}{5437}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ، اللَّهِ بْنِ حُنَيْنٍ عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الْقَسِّيِّ وَالْمُعَصْفَرِ وَعَنْ تَخَتُّمِ الذَّهَبِ وَعَنْ قِرَاءَةِ الْقُرْآنِ فِي الرُّكُوعِ ‏.‏\hadithno{5437}\hadithtrans{Ali b. Abu Talib reported that Allah's Messenger (ﷺ) forbade wearing of silk and yellow clothes, and the gold ring, and the reciting of the Qur'an in the ruku' (state of kneeling in prayer)}}
\hadithdefcmd{muslim}{5438}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ نَهَانِي النَّبِيُّ صلى الله عليه وسلم عَنِ الْقِرَاءَةِ وَأَنَا رَاكِعٌ وَعَنْ لُبْسِ الذَّهَبِ وَالْمُعَصْفَرِ ‏.‏\hadithno{5438}\hadithtrans{Ali b. Abu Talib reported:Allah's Apostle (ﷺ) forbade me to recite the Qur'an while I am in ruku; and the wearing of gold and clothes dyed in saffron}}
\hadithdefcmd{muslim}{5439}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ إِبْرَاهِيمَ، بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّخَتُّمِ بِالذَّهَبِ وَعَنْ لِبَاسِ الْقَسِّيِّ وَعَنِ الْقِرَاءَةِ فِي الرُّكُوعِ وَالسُّجُودِ وَعَنْ لِبَاسِ الْمُعَصْفَرِ ‏.‏\hadithno{5439}\hadithtrans{Ali b. Abu Talib reported:Allah's Messenger (ﷺ) forbade me to use gold rings. to wear silk clothes and to recite the Qur'an in ruku' and sajda (prostration), and to wear yellow garments}}
\hadithdefcmd{muslim}{5440}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، قَالَ قُلْنَا لأَنَسِ بْنِ مَالِكٍ أَىُّ اللِّبَاسِ كَانَ أَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَوْ أَعْجَبَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ الْحِبَرَةُ ‏.‏\hadithno{5440}\hadithtrans{(Qatada said:We asked Anas b. Malik which garment did Allah's Messenger may peace be upon him) love or like (to wear). He said: The mantle of Yemen}}
\hadithdefcmd{muslim}{5441}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ أَحَبَّ الثِّيَابِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْحِبَرَةُ ‏.‏\hadithno{5441}\hadithtrans{Anas reported that the garment most liked by Allah's Messenger (ﷺ) was the mantle of Yemen}}
\hadithdefcmd{muslim}{5442}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَبِي بُرْدَةَ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ فَأَخْرَجَتْ إِلَيْنَا إِزَارًا غَلِيظًا مِمَّا يُصْنَعُ بِالْيَمَنِ وَكِسَاءً مِنَ الَّتِي يُسَمُّونَهَا الْمُلَبَّدَةَ - قَالَ - فَأَقْسَمَتْ بِاللَّهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قُبِضَ فِي هَذَيْنِ الثَّوْبَيْنِ ‏.‏\hadithno{5442}\hadithtrans{Abu Burda reported:I visited A'isha and she brought out for us the coarse lower garfnent (of Allah's Messenger) made in Yemen and clothes made out of Mulabbada cloth, and she swore in the name of Allah that Allah's Messenger (ﷺ) died in these two clothes}}
\hadithdefcmd{muslim}{5443}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَمُحَمَّدُ بْنُ حَاتِمٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، قَالَ ابْنُ حُجْرٍ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ، قَالَ أَخْرَجَتْ إِلَيْنَا عَائِشَةُ إِزَارًا وَكِسَاءً مُلَبَّدًا فَقَالَتْ فِي هَذَا قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ابْنُ حَاتِمٍ فِي حَدِيثِهِ إِزَارًا غَلِيظًا ‏.‏\hadithno{5443}\hadithtrans{Abu Burda reported that A'isha brought out for us the lower garment and the upper garment made of the Mulabbada cloth and said:It was in these (clothes) that Allah's Messenger (ﷺ) died. Ibn Hatim (one of the narrators) in his narration Wd: The lower garment of coarse cloth}}
\hadithdefcmd{muslim}{5444}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَقَالَ إِزَارًا غَلِيظًا ‏.‏\hadithno{5444}\hadithtrans{This hadith has been reported on the authority of Ayyub with a slight variation of wording}}
\hadithdefcmd{muslim}{5445}{وَحَدَّثَنِي سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، ح وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، بْنُ زَكَرِيَّاءَ أَخْبَرَنِي أَبِي، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، قَالَتْ خَرَجَ النَّبِيُّ صلى الله عليه وسلم ذَاتَ غَدَاةٍ وَعَلَيْهِ مِرْطٌ مُرَحَّلٌ مِنْ شَعَرٍ أَسْوَدَ ‏.‏\hadithno{5445}\hadithtrans{A'isha reported that Allah's Apostle (ﷺ) went out one morning wearing a blanket made of (camel's or sheep's) black hair with patterns of camel saddles upon it}}
\hadithdefcmd{muslim}{5446}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ وِسَادَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي يَتَّكِئُ عَلَيْهَا مِنْ أَدَمٍ حَشْوُهَا لِيفٌ ‏.‏\hadithno{5446}\hadithtrans{A'isha reported that the pillow on which Allah's Messenger (ﷺ) reclined was of leather stuffed with palm fibre}}
\hadithdefcmd{muslim}{5447}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّمَا كَانَ فِرَاشُ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّذِي يَنَامُ عَلَيْهِ أَدَمًا حَشْوُهُ لِيفٌ ‏.‏\hadithno{5447}\hadithtrans{A'isha reported that the bedding on which. Allah's Messenger (ﷺ) slept was made of leather stuffed with palm fibre}}
\hadithdefcmd{muslim}{5448}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، كِلاَهُمَا عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ وَقَالاَ ضِجَاعُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فِي حَدِيثِ أَبِي مُعَاوِيَةَ يَنَامُ عَلَيْهِ ‏.‏\hadithno{5448}\hadithtrans{This hadith has been reported on the authority of Hisham b. 'Urwa with a slight variation of wording}}
\hadithdefcmd{muslim}{5449}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعَمْرٍو - قَالَ عَمْرٌو وَقُتَيْبَةُ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا سُفْيَانُ، عَنِ ابْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم لَمَّا تَزَوَّجْتُ ‏"‏ أَتَّخَذْتَ أَنْمَاطًا ‏"‏ ‏.‏ قُلْتُ وَأَنَّى لَنَا أَنْمَاطٌ قَالَ ‏"‏ أَمَا إِنَّهَا سَتَكُونُ ‏"‏ ‏.‏\hadithno{5449}\hadithtrans{Jabir reported:When I was married, Allah's Messenger (may peace he upon him) asked me if I had got the carpet. I said: How can we have carpets? (i. e. I am so poor that I cannot even think of carpets). whereupon he said: You shall soon possess them}}
\hadithdefcmd{muslim}{5450}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ لَمَّا تَزَوَّجْتُ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَّخَذْتَ أَنْمَاطًا ‏"‏ ‏.‏ قُلْتُ وَأَنَّى لَنَا أَنْمَاطٌ قَالَ ‏"‏ أَمَا إِنَّهَا سَتَكُونُ ‏"‏ ‏.‏ قَالَ جَابِرٌ وَعِنْدَ امْرَأَتِي نَمَطٌ فَأَنَا أَقُولُ نَحِّيهِ عَنِّي ‏.‏ وَتَقُولُ قَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهَا سَتَكُونُ ‏"‏ ‏.‏\hadithno{5450}\hadithtrans{Jabir b. Abdullah reported:When I was married. Allah's Messenger (ﷺ) asked me if I had got carpets. I said: How can we have carpets? Thereupon he said: You will soon have. Jabir said: My wife had possessed a carpet, and I said to her to remove that away from me, but she would say: Allah's Messenger (ﷺ) had said: You will soon have}}
\hadithdefcmd{muslim}{5451}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، بِهَذَا الإِسْنَادِ وَزَادَ فَأَدَعُهَا ‏.‏\hadithno{5451}\hadithtrans{This hadith has been narrated on the authority of Sufyan with the saule chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5452}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أَبُو هَانِئٍ، أَنَّهُ سَمِعَ أَبَا عَبْدِ الرَّحْمَنِ، يَقُولُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ فِرَاشٌ لِلرَّجُلِ وَفِرَاشٌ لاِمْرَأَتِهِ وَالثَّالِثُ لِلضَّيْفِ وَالرَّابِعُ لِلشَّيْطَانِ ‏"‏ ‏.‏\hadithno{5452}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Messengor (ﷺ) said:There should be a bedding for a man. a bedding for his wife and the third one for the guest, and the fourth one is for the Satan}}
\hadithdefcmd{muslim}{5453}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، وَزَيْدِ، بْنِ أَسْلَمَ كُلُّهُمْ يُخْبِرُهُ عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْظُرُ اللَّهُ إِلَى مَنْ جَرَّ ثَوْبَهُ خُيَلاَءَ ‏"‏ ‏.‏\hadithno{5453}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) having said:Allah will not look upon him who trails his garment out of pride}}
\hadithdefcmd{muslim}{5454}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، كِلاَهُمَا عَنْ أَيُّوبَ، ح وَحَدَّثَنَا قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا هَارُونُ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أُسَامَةُ، كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ مَالِكٍ وَزَادُوا فِيهِ ‏ "‏ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5454}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar through other chains of transmitters also with the addition of these words:" On the Day of Resurrection}}
\hadithdefcmd{muslim}{5455}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عُمَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، وَسَالِمِ بْنِ عَبْدِ اللَّهِ وَنَافِعٍ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الَّذِي يَجُرُّ ثِيَابَهُ مِنَ الْخُيَلاَءِ لاَ يَنْظُرُ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5455}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) having said:He who trails his (lower) garment out of pride, Allah will not look toward him on the Day of Resurrection}}
\hadithdefcmd{muslim}{5456}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كِلاَهُمَا عَنْ مُحَارِبِ بْنِ دِثَارٍ، وَجَبَلَةَ بْنِ، سُحَيْمٍ عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِهِمْ ‏.‏\hadithno{5456}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{5457}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا حَنْظَلَةُ، قَالَ سَمِعْتُ سَالِمًا، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ جَرَّ ثَوْبَهُ مِنَ الْخُيَلاَءِ لَمْ يَنْظُرِ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5457}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) having said:He who trailed his garment out of pride, Allah would not look toward him on the Day of Resurrection}}
\hadithdefcmd{muslim}{5458}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، حَدَّثَنَا حَنْظَلَةُ بْنُ أَبِي سُفْيَانَ، قَالَ سَمِعْتُ سَالِمًا، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ ثِيَابَهُ ‏.‏\hadithno{5458}\hadithtrans{Salim reported:I heard Ibn Umar as saying that he had heard Allah's Messenger (ﷺ) as saying like this (as mentioned above) but with a slight variation of wording [that instead of the word thaub (cloth) there is the word thiyab (the clothes)}}
\hadithdefcmd{muslim}{5459}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ مُسْلِمَ، بْنَ يَنَّاقَ يُحَدِّثُ عَنِ ابْنِ عُمَرَ، أَنَّهُ رَأَى رَجُلاً يَجُرُّ إِزَارَهُ فَقَالَ مِمَّنْ أَنْتَ فَانْتَسَبَ لَهُ فَإِذَا رَجُلٌ مِنْ بَنِي لَيْثٍ فَعَرَفَهُ ابْنُ عُمَرَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِأُذُنَىَّ هَاتَيْنِ يَقُولُ ‏ "‏ مَنْ جَرَّ إِزَارَهُ لاَ يُرِيدُ بِذَلِكَ إِلاَّ الْمَخِيلَةَ فَإِنَّ اللَّهَ لاَ يَنْظُرُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5459}\hadithtrans{Muslim b. Yannaq reported that Ibn Umar saw a person trailing his lower garment, whereupon he said:From whom do you come? He described his relationship (with the tribe he belonged) and it was found that he belonged to the tribe of Laith. Ibn. Umar recognised him and said: I heard Allah's Messenger (ﷺ) with these two ears of mine saying: He who trailed his lower garment with no other intention but pride, Allah would not look toward him on the Day of Resurrection}}
\hadithdefcmd{muslim}{5460}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ، - يَعْنِي ابْنَ أَبِي سُلَيْمَانَ - ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو يُونُسَ، ح وَحَدَّثَنَا ابْنُ أَبِي خَلَفٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنِي إِبْرَاهِيمُ، - يَعْنِي ابْنَ نَافِعٍ - كُلُّهُمْ عَنْ مُسْلِمِ بْنِ يَنَّاقَ، عَنِ ابْنِ، عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّ فِي حَدِيثِ أَبِي يُونُسَ عَنْ مُسْلِمٍ أَبِي الْحَسَنِ وَفِي رِوَايَتِهِمْ جَمِيعًا ‏ "‏ مَنْ جَرَّ إِزَارَهُ ‏"‏ ‏.‏ وَلَمْ يَقُولُوا ثَوْبَهُ ‏.‏\hadithno{5460}\hadithtrans{This hadith has been narrated on the authority of Muslim b. Yannaq through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5461}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، وَابْنُ أَبِي خَلَفٍ، وَأَلْفَاظُهُمْ، مُتَقَارِبَةٌ قَالُوا حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ عَبَّادِ بْنِ جَعْفَرٍ، يَقُولُ أَمَرْتُ مُسْلِمَ بْنَ يَسَارٍ مَوْلَى نَافِعِ بْنِ عَبْدِ الْحَارِثِ أَنْ يَسْأَلَ ابْنَ عُمَرَ، - قَالَ - وَأَنَا جَالِسٌ، بَيْنَهُمَا أَسَمِعْتَ مِنَ النَّبِيِّ صلى الله عليه وسلم فِي الَّذِي يَجُرُّ إِزَارَهُ مِنَ الْخُيَلاَءِ شَيْئًا قَالَ سَمِعْتُهُ يَقُولُ ‏ "‏ لاَ يَنْظُرُ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5461}\hadithtrans{Muhammad b. 'Abbad b. Ja'far reported:I ordered Muslim b. Yasar, the freed slave of Nafi' b. 'Abd al-Harith, while I was sitting between them, that he should ask Ibn 'Umar if he had heard anything from Allah's Messenger (ﷺ) pertaining to one who trails his lower garment out of pride. He said: I heard him (the Holy Prophet) as saying: Allah will not look toward him on the Day of Resurrection}}
\hadithdefcmd{muslim}{5462}{حَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عُمَرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ، وَاقِدٍ عَنِ ابْنِ عُمَرَ، قَالَ مَرَرْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي إِزَارِي اسْتِرْخَاءٌ فَقَالَ ‏"‏ يَا عَبْدَ اللَّهِ ارْفَعْ إِزَارَكَ ‏"‏ ‏.‏ فَرَفَعْتُهُ ثُمَّ قَالَ ‏"‏ زِدْ ‏"‏ ‏.‏ فَزِدْتُ فَمَا زِلْتُ أَتَحَرَّاهَا بَعْدُ ‏.‏ فَقَالَ بَعْضُ الْقَوْمِ إِلَى أَيْنَ فَقَالَ أَنْصَافِ السَّاقَيْنِ ‏.‏\hadithno{5462}\hadithtrans{Ibn 'Umar reported:I happened to pass before Allah's Messenger (may peace be upon bin) with my lower garment trailing (upon the ground). He said: 'Abdullah, tug up your lower garment,, I tugged it up, and he again said: Tug it still further, and I tugged it still further and I went on tugging it afterward, whereupon some of the people said: To what extent? Thereupon he said: To the middle of the shanks}}
\hadithdefcmd{muslim}{5463}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدٍ، - وَهُوَ ابْنُ زِيَادٍ - قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، وَرَأَى، رَجُلاً يَجُرُّ إِزَارَهُ فَجَعَلَ يَضْرِبُ الأَرْضَ بِرِجْلِهِ وَهُوَ أَمِيرٌ عَلَى الْبَحْرَيْنِ وَهُوَ يَقُولُ جَاءَ الأَمِيرُ جَاءَ الأَمِيرُ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ لاَ يَنْظُرُ إِلَى مَنْ يَجُرُّ إِزَارَهُ بَطَرًا ‏"‏ ‏.‏\hadithno{5463}\hadithtrans{Abu Huraire reported that he saw a person whose lower garment bad been trailin. and he was striking the ground with his foot (conceitedly). He was the Amir of Bahrain and it was being said:Here comes the Amir, here comes the Amir. He (Abu Huraira) reported that Allah's Messenger (ﷺ) said: Allah will not look toward him who trails his lower garment out of pride}}
\hadithdefcmd{muslim}{5464}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ يَعْنِي ابْنَ جَعْفَرٍ، ح وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ ابْنِ جَعْفَرٍ كَانَ مَرْوَانُ يَسْتَخْلِفُ أَبَا هُرَيْرَةَ ‏.‏ وَفِي حَدِيثِ ابْنِ الْمُثَنَّى كَانَ أَبُو هُرَيْرَةَ يُسْتَخْلَفُ عَلَى الْمَدِينَةِ ‏.‏\hadithno{5464}\hadithtrans{This hadith has been reported on the authority of Shu'ba with the same chain of transmitters and in the hadith transmitted on the authority of Ibn ja'far (the words are):Marwan had made Abu Huraira as his deputy. and in the hadith transmitted on the authority of Ibn Muthanna (the words are). Abu Huraira was the Governor of Medina}}
\hadithdefcmd{muslim}{5465}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، حَدَّثَنَا الرَّبِيعُ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا رَجُلٌ يَمْشِي قَدْ أَعْجَبَتْهُ جُمَّتُهُ وَبُرْدَاهُ إِذْ خُسِفَ بِهِ الأَرْضُ فَهُوَ يَتَجَلْجَلُ فِي الأَرْضِ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏\hadithno{5465}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said that there was a person who used to walk with pride because of his thick hair and fine mantles. He was made to sink in the earth and he would go on sinking in the earth until the Last Hour would come}}
\hadithdefcmd{muslim}{5466}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدِ بْنِ، جَعْفَرٍ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، قَالُوا جَمِيعًا حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ هَذَا ‏.‏\hadithno{5466}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira but with a different chain of transmitters}}
\hadithdefcmd{muslim}{5467}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا رَجُلٌ يَتَبَخْتَرُ يَمْشِي فِي بُرْدَيْهِ قَدْ أَعْجَبَتْهُ نَفْسُهُ فَخَسَفَ اللَّهُ بِهِ الأَرْضَ فَهُوَ يَتَجَلْجَلُ فِيهَا إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{5467}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There was a person who walked with pride because of his (fine) mantles and well pleased with his personality. Allah made him sink in the earth and he would go on sinking in that until the Day of Resurrection}}
\hadithdefcmd{muslim}{5468}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَيْنَمَا رَجُلٌ يَتَبَخْتَرُ فِي بُرْدَيْنِ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{5468}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira but with a slight variation of wording:While there was a man who strutted in his two mantles}}
\hadithdefcmd{muslim}{5469}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ رَجُلاً مِمَّنْ كَانَ قَبْلَكُمْ يَتَبَخْتَرُ فِي حُلَّةٍ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ مِثْلَ حَدِيثِهِمْ ‏.‏\hadithno{5469}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There was a person (living before you) who took pride in his cloak. the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5470}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ خَاتَمِ الذَّهَبِ ‏.‏\hadithno{5470}\hadithtrans{Abu Huraira reported that Allah's Apostle (ﷺ) forbade the wearing of gold signet ring}}
\hadithdefcmd{muslim}{5471}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5471}\hadithtrans{The previous hadith is narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{5472}{وَفِي حَدِيثِ ابْنِ الْمُثَنَّى قَالَ سَمِعْتُ النَّضْرَ بْنَ أَنَسٍ، حَدَّثَنِي مُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنِي إِبْرَاهِيمُ بْنُ عُقْبَةَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى خَاتَمًا مِنْ ذَهَبٍ فِي يَدِ رَجُلٍ فَنَزَعَهُ فَطَرَحَهُ وَقَالَ ‏ "‏ يَعْمِدُ أَحَدُكُمْ إِلَى جَمْرَةٍ مِنْ نَارٍ فَيَجْعَلُهَا فِي يَدِهِ ‏"‏ ‏.‏ فَقِيلَ لِلرَّجُلِ بَعْدَ مَا ذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم خُذْ خَاتَمَكَ انْتَفِعْ بِهِ ‏.‏ قَالَ لاَ وَاللَّهِ لاَ آخُذُهُ أَبَدًا وَقَدْ طَرَحَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5472}\hadithtrans{Abdullah b. 'Abbas reported that Allah's Messenger (ﷺ) saw a person wearing a gold signet ring in his hand. He (the Holy Prophet) pulled it off and threw it away, saying:One of you is wishing live coal from Hell. and putting it on his hand. It was said to the person after Allah's Messenger (ﷺ) had left: Take your signet ring (of gold) and derive benefit out of it. whereupon he said: No, by Allah, I would never take it when Allah's Messenger (ﷺ) has thrown it away}}
\hadithdefcmd{muslim}{5473}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اصْطَنَعَ خَاتَمًا مِنْ ذَهَبٍ فَكَانَ يَجْعَلُ فَصَّهُ فِي بَاطِنِ كَفِّهِ إِذَا لَبِسَهُ فَصَنَعَ النَّاسُ ثُمَّ إِنَّهُ جَلَسَ عَلَى الْمِنْبَرِ فَنَزَعَهُ فَقَالَ ‏"‏ إِنِّي كُنْتُ أَلْبَسُ هَذَا الْخَاتِمَ وَأَجْعَلُ فَصَّهُ مِنْ دَاخِلٍ ‏"‏ ‏.‏ فَرَمَى بِهِ ثُمَّ قَالَ ‏"‏ وَاللَّهِ لاَ أَلْبَسُهُ أَبَدًا ‏"‏ ‏.‏ فَنَبَذَ النَّاسُ خَوَاتِيمَهُمْ ‏.‏ وَلَفْظُ الْحَدِيثِ لِيَحْيَى ‏.‏\hadithno{5473}\hadithtrans{Abdullah reported that Allah's Messenger (may peace be upol him) got fashioned a signet ring of gold but he kept its stone on the inner side of his palm as he wore it, so the people (following his example) got fashioned (such rings). Then one day as he sat on the pulpit he pulled it away saying:I wore this ring and kept its stone towards the inner side. He then threw it away, and said: By Allah, I will never wear it; so the people threw their rings away}}
\hadithdefcmd{muslim}{5474}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، ح وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنَا سَهْلُ، بْنُ عُثْمَانَ حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ فِي خَاتِمِ الذَّهَبِ وَزَادَ فِي حَدِيثِ عُقْبَةَ بْنِ خَالِدٍ وَجَعَلَهُ فِي يَدِهِ الْيُمْنَى ‏.‏\hadithno{5474}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar through other chains of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5475}{وَحَدَّثَنِيهِ أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ، إِسْحَاقَ الْمُسَيَّبِيُّ حَدَّثَنَا أَنَسٌ، - يَعْنِي ابْنَ عِيَاضٍ - عَنْ مُوسَى بْنِ عُقْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ عَبَّادٍ حَدَّثَنَا حَاتِمٌ، ح وَحَدَّثَنَا هَارُونُ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، كُلُّهُمْ عَنْ أُسَامَةَ، جَمَاعَتُهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي خَاتِمِ الذَّهَبِ ‏.‏ نَحْوَ حَدِيثِ اللَّيْثِ ‏.‏\hadithno{5475}\hadithtrans{This hadith has also been likewise narrated on the authority of Ibn 'Umar through several other chains of transmitters}}
\hadithdefcmd{muslim}{5476}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ وَرِقٍ فَكَانَ فِي يَدِهِ ثُمَّ كَانَ فِي يَدِ أَبِي بَكْرٍ ثُمَّ كَانَ فِي يَدِ عُمَرَ ثُمَّ كَانَ فِي يَدِ عُثْمَانَ حَتَّى وَقَعَ مِنْهُ فِي بِئْرِ أَرِيسٍ نَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏ قَالَ ابْنُ نُمَيْرٍ حَتَّى وَقَعَ فِي بِئْرِ ‏.‏ وَلَمْ يَقُلْ مِنْهُ ‏.‏\hadithno{5476}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) had made for himself a ring of silver, and he (wore it in his finger). then it was in Abu Bakr's finger. then it was in'Umar's finger. then it was in 'Uthman's finger. until it fell into the well of Aris and it had these words engraved upon it (Muhammad, Messenger of Allah). Ibn Numair narrated it with a slight variation of words}}
\hadithdefcmd{muslim}{5477}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَمُحَمَّدُ بْنُ عَبَّادٍ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ، عُمَرَ قَالَ اتَّخَذَ النَّبِيُّ صلى الله عليه وسلم خَاتَمًا مِنْ ذَهَبٍ ثُمَّ أَلْقَاهُ ثُمَّ اتَّخَذَ خَاتَمًا مِنْ وَرِقٍ وَنَقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏ وَقَالَ ‏ "‏ لاَ يَنْقُشْ أَحَدٌ عَلَى نَقْشِ خَاتَمِي هَذَا ‏"‏ ‏.‏ وَكَانَ إِذَا لَبِسَهُ جَعَلَ فَصَّهُ مِمَّا يَلِي بَطْنَ كَفِّهِ وَهُوَ الَّذِي سَقَطَ مِنْ مُعَيْقِيبٍ فِي بِئْرِ أَرِيسٍ ‏.‏\hadithno{5477}\hadithtrans{Ibn Umar reported that Allah's Apostle (ﷺ) had made for himself a gold ring; then he discarded it, and then made for himself a silver ring, and had these words engraved upon it (Muhammad, Messenger of Allah), and said:No one should engrave anything like the engraving of this signet ring of mine. And when he wore it, he kept its stone towards the inside of his palm, and it was this which fell down (from the hands) of Mu'ayqib into the well of Aris}}
\hadithdefcmd{muslim}{5478}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَخَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ الْعَتَكِيُّ، كُلُّهُمْ عَنْ حَمَّادٍ، - قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّوسلم اتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ وَنَقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏ وَقَالَ لِلنَّاسِ ‏ "‏ إِنِّي اتَّخَذْتُ خَاتَمًا مِنْ فِضَّةٍ وَنَقَشْتُ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏ فَلاَ يَنْقُشْ أَحَدٌ عَلَى نَقْشِهِ ‏"‏ ‏.‏\hadithno{5478}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) had made for him a silver ring. and got engraved on it (Muhammad, Messenger of Allah) and said to the people I have got made a ring of silver and engraved in it (these words) (Muhammad, Messenger of Allah). So none should engrave these (words) like this engravement}}
\hadithdefcmd{muslim}{5479}{وَحَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا وَلَمْ يَذْكُرْ فِي الْحَدِيثِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{5479}\hadithtrans{This hadith has been reported on the authority of Anas through another chain of transmitters but there is no mention of the words (Muhammad, Messenger of Allah) in it}}
\hadithdefcmd{muslim}{5480}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا أَرَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَكْتُبَ إِلَى الرُّومِ - قَالَ - قَالُوا إِنَّهُمْ لاَ يَقْرَءُونَ كِتَابًا إِلاَّ مَخْتُومًا ‏.‏ قَالَ فَاتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ فِضَّةٍ كَأَنِّي أَنْظُرُ إِلَى بَيَاضِهِ فِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَقْشُهُ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{5480}\hadithtrans{Anas b. Malik reported that when Allah's Messenger (ﷺ) decided to write letters to the Byzantine (Emperor) they (his Companions) told him that they would not read a letter unless it is sealed. (Then) Allah's Messenger (ﷺ) had a silver ring made (for himself), (its shape is so vivid in my mind) as if I see its brightness in the band of Allah's Messenger (ﷺ) and its engravement was (Muhammad, Messenger of Allah)}}
\hadithdefcmd{muslim}{5481}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ أَرَادَ أَنْ يَكْتُبَ إِلَى الْعَجَمِ فَقِيلَ لَهُ إِنَّ الْعَجَمَ لاَ يَقْبَلُونَ إِلاَّ كِتَابًا عَلَيْهِ خَاتِمٌ ‏.‏ فَاصْطَنَعَ خَاتَمًا مِنْ فِضَّةٍ ‏.‏ قَالَ كَأَنِّي أَنْظُرُ إِلَى بَيَاضِهِ فِي يَدِهِ ‏.‏\hadithno{5481}\hadithtrans{Anas reported that when Allah's Apostle (ﷺ) decided to write (letters) to non-Arabs (i. e. Persian and Byzantine Emperors) it was said to him that the non-Arabs would not accept a letter but that having a seal over it; so he (the Holy Prophet) got a silver ring made. He (Anas) said:I perceive as if I am looking at its brightness in his hand}}
\hadithdefcmd{muslim}{5482}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا نُوحُ بْنُ قَيْسٍ، عَنْ أَخِيهِ، خَالِدِ بْنِ قَيْسٍ عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَرَادَ أَنْ يَكْتُبَ إِلَى كِسْرَى وَقَيْصَرَ وَالنَّجَاشِيِّ ‏.‏ فَقِيلَ إِنَّهُمْ لاَ يَقْبَلُونَ كِتَابًا إِلاَّ بِخَاتِمٍ ‏.‏ فَصَاغَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا حَلَقَةً فِضَّةً وَنَقَشَ فِيهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏.‏\hadithno{5482}\hadithtrans{Anas reported that when Allah's Apostle (ﷺ) decided to write to the Kisra (the King of Persia), Caesar (Emperor of Rome), and the Negus (the Emperor of Abyssinia), it was said to him that they would not accept the letter without the seal over it; so Allah's Messenger (ﷺ) got a seal made, the ring of which was made of silver and there was engraved on it:"Muhammad, the Messenger of Allah}}
\hadithdefcmd{muslim}{5483}{حَدَّثَنِي أَبُو عِمْرَانَ، مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ أَخْبَرَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ أَبْصَرَ فِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ وَرِقٍ يَوْمًا وَاحِدًا - قَالَ - فَصَنَعَ النَّاسُ الْخَوَاتِمَ مِنْ وَرِقٍ فَلَبِسُوهُ فَطَرَحَ النَّبِيُّ صلى الله عليه وسلم خَاتَمَهُ فَطَرَحَ النَّاسُ خَوَاتِمَهُمْ ‏.‏\hadithno{5483}\hadithtrans{Anas b. Malik reported:I saw one day on the finger of Allah's Messenger (may peace be Upon him) a silver ring; so the people also got silver rings made and wore them Then Allah's Apostle (ﷺ) discarded his ring, and the people also discarded their rings}}
\hadithdefcmd{muslim}{5484}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا رَوْحٌ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي زِيَادٌ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ أَنَّ أَنَسَ بْنَ مَالِكٍ أَخْبَرَهُ أَنَّهُ، رَأَى فِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ وَرِقٍ يَوْمًا وَاحِدًا ثُمَّ إِنَّ النَّاسَ اضْطَرَبُوا الْخَوَاتِمَ مِنْ وَرِقٍ فَلَبِسُوهَا فَطَرَحَ النَّبِيُّ صلى الله عليه وسلم خَاتَمَهُ فَطَرَحَ النَّاسُ خَوَاتِمَهُمْ ‏.‏\hadithno{5484}\hadithtrans{Anas b. Malik reported that one day he saw on the finger of Allah's Messenger (ﷺ) a silver ring, and the people also made silver rings and put them on. Then Allah's Apostle (ﷺ) threw his ring away, and so the people also threw away their rings}}
\hadithdefcmd{muslim}{5485}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5485}\hadithtrans{A hadith like this has been reported on the authority of Ibn Juraij with the same chain of transmitters}}
\hadithdefcmd{muslim}{5486}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ الْمِصْرِيُّ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ كَانَ خَاتِمُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ وَرِقٍ وَكَانَ فَصُّهُ حَبَشِيًّا ‏.‏\hadithno{5486}\hadithtrans{Anas b. Malik reported that the ring of Allah's Messenger (ﷺ) was made of silver and it had an Abyssinian stone in it}}
\hadithdefcmd{muslim}{5487}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَعَبَّادُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، - وَهُوَ الأَنْصَارِيُّ ثُمَّ الزُّرَقِيُّ - عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَبِسَ خَاتَمَ فِضَّةٍ فِي يَمِينِهِ فِيهِ فَصٌّ حَبَشِيٌّ كَانَ يَجْعَلُ فَصَّهُ مِمَّا يَلِي كَفَّهُ ‏.‏\hadithno{5487}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) wore a silver ring on his right hand which had an Abyssinian stone in it, and he kept its stone towards the palm}}
\hadithdefcmd{muslim}{5488}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ، بِلاَلٍ عَنْ يُونُسَ بْنِ يَزِيدَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ طَلْحَةَ بْنِ يَحْيَى ‏.‏\hadithno{5488}\hadithtrans{This hadith has been narrated on the authority of Yunus b. Yazid with the same chain of transmitters}}
\hadithdefcmd{muslim}{5489}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا حَمَّادُ، بْنُ سَلَمَةَ عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ خَاتِمُ النَّبِيِّ صلى الله عليه وسلم فِي هَذِهِ ‏.‏ وَأَشَارَ إِلَى الْخِنْصَرِ مِنْ يَدِهِ الْيُسْرَى ‏.‏\hadithno{5489}\hadithtrans{Anas reported that the ring of Allah's Apostle (ﷺ) was on this, and he pointed toward the little finger of his left hand}}
\hadithdefcmd{muslim}{5490}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنِ ابْنِ إِدْرِيسَ، - وَاللَّفْظُ لأَبِي كُرَيْبٍ - حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ عَاصِمَ بْنَ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، عَنْ عَلِيٍّ، قَالَ نَهَانِي - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - أَنْ أَجْعَلَ خَاتَمِي فِي هَذِهِ أَوِ الَّتِي تَلِيهَا - لَمْ يَدْرِ عَاصِمٌ فِي أَىِّ الثِّنْتَيْنِ - وَنَهَانِي عَنْ لُبْسِ الْقَسِّيِّ وَعَنْ جُلُوسٍ عَلَى الْمَيَاثِرِ ‏.‏ قَالَ فَأَمَّا الْقَسِّيُّ فَثِيَابٌ مُضَلَّعَةٌ يُؤْتَى بِهَا مِنْ مِصْرَ وَالشَّامِ فِيهَا شِبْهُ كَذَا وَأَمَّا الْمَيَاثِرُ فَشَىْءٌ كَانَتْ تَجْعَلُهُ النِّسَاءُ لِبُعُولَتِهِنَّ عَلَى الرَّحْلِ كَالْقَطَائِفِ الأُرْجُوَانِ ‏.‏\hadithno{5490}\hadithtrans{Ali reported:He the Prophet (ﷺ), forbade me that I should wear my ring in this (forefinger) or in that near it. 'Asim (one of the narrators in the chain of transmitters) said: He did not remember which of the two (fingers) he pointed out; and he forbade to wear Qassi material (silk garments), and to sit on the silk saddle cloth, and he said: As regards Qassi, it is a variegated garment which was brought from Egypt and Syria which had figures upon it, and as regards Mayathir, it is something which women prepared for their husbands as red cloths for their saddles}}
\hadithdefcmd{muslim}{5491}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنِ ابْنٍ لأَبِي، مُوسَى قَالَ سَمِعْتُ عَلِيًّا، ‏.‏ فَذَكَرَ هَذَا الْحَدِيثَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{5491}\hadithtrans{A hadith like this has been reported on the authority of 'Ali through a different chain of transmitters}}
\hadithdefcmd{muslim}{5492}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، قَالَ سَمِعْتُ أَبَا بُرْدَةَ، قَالَ سَمِعْتُ عَلِيَّ بْنَ أَبِي طَالِبٍ، قَالَ نَهَى أَوْ نَهَانِي يَعْنِي النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{5492}\hadithtrans{Ali b. Abu Talib reported that he (Allah'. s Apostle) forbade or forbade me. the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5493}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو الأَحْوَصِ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، قَالَ قَالَ عَلِيٌّ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَتَخَتَّمَ فِي إِصْبَعِي هَذِهِ أَوْ هَذِهِ ‏.‏ قَالَ فَأَوْمَأَ إِلَى الْوُسْطَى وَالَّتِي تَلِيهَا ‏.‏\hadithno{5493}\hadithtrans{Ali reported:Allah's Messenger (ﷺ) forbade me that I should wear a ring in this and that finger of mine, and he pointed to the middle finger and the next one}}
\hadithdefcmd{muslim}{5494}{حَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ فِي غَزْوَةٍ غَزَوْنَاهَا ‏ "‏ اسْتَكْثِرُوا مِنَ النِّعَالِ فَإِنَّ الرَّجُلَ لاَ يَزَالُ رَاكِبًا مَا انْتَعَلَ ‏"‏ ‏.‏\hadithno{5494}\hadithtrans{Jabir reported:I heard Allah's Apostle (ﷺ) saying during an expedition in which we also participated: Make a general practice of wearing sandals, for a man is riding as it were when he wears sandals}}
\hadithdefcmd{muslim}{5495}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، حَدَّثَنَا الرَّبِيعُ بْنُ مُسْلِمٍ، عَنْ مُحَمَّدٍ، - يَعْنِي ابْنَ زِيَادٍ - عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا انْتَعَلَ أَحَدُكُمْ فَلْيَبْدَأْ بِالْيُمْنَى وَإِذَا خَلَعَ فَلْيَبْدَأْ بِالشِّمَالِ وَلْيُنْعِلْهُمَا جَمِيعًا أَوْ لِيَخْلَعْهُمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{5495}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:"When one of you puts on sandals, he should first put in the right foot, and when he takes off he should take off the left one first. And he should wear both of them or take both off}}
\hadithdefcmd{muslim}{5496}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْشِ أَحَدُكُمْ فِي نَعْلٍ وَاحِدَةٍ لِيُنْعِلْهُمَا جَمِيعًا أَوْ لِيَخْلَعْهُمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{5496}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None of you should walk in one sandal; either he should wear the two or should take off the two}}
\hadithdefcmd{muslim}{5497}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالاَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، عَنْ أَبِي رَزِينٍ، قَالَ خَرَجَ إِلَيْنَا أَبُو هُرَيْرَةَ فَضَرَبَ بِيَدِهِ عَلَى جَبْهَتِهِ فَقَالَ أَلاَ إِنَّكُمْ تَحَدَّثُونَ أَنِّي أَكْذِبُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لِتَهْتَدُوا وَأَضِلَّ أَلاَ وَإِنِّي أَشْهَدُ لَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا انْقَطَعَ شِسْعُ أَحَدِكُمْ فَلاَ يَمْشِ فِي الأُخْرَى حَتَّى يُصْلِحَهَا ‏"‏ ‏.‏\hadithno{5497}\hadithtrans{Abu Razin reported:Abu Huraira came to us and he struck his forehead with his hand and said: Behold I you talk amongst yourself that I attribute wrongly to Allah's Messenger (ﷺ) (certain things) in order to guide you to the right path. In such a case, I would myself go astray. Listen. I bear testimony to the fact that I heard Allah's Messenger (ﷺ) saying: When the thong of any one of you is broken, he should not walk in the second one until he has got it repaired}}
\hadithdefcmd{muslim}{5498}{وَحَدَّثَنِيهِ عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، أَخْبَرَنَا الأَعْمَشُ، عَنْ أَبِي رَزِينٍ، وَأَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْمَعْنَى ‏.‏\hadithno{5498}\hadithtrans{This hadith has been reported on the authority of Abu Huraira with a different chain of transmitters}}
\hadithdefcmd{muslim}{5499}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، - فِيمَا قُرِئَ عَلَيْهِ - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يَأْكُلَ الرَّجُلَ بِشِمَالِهِ أَوْ يَمْشِيَ فِي نَعْلٍ وَاحِدَةٍ وَأَنْ يَشْتَمِلَ الصَّمَّاءَ وَأَنْ يَحْتَبِيَ فِي ثَوْبٍ وَاحِدٍ كَاشِفًا عَنْ فَرْجِهِ ‏.‏\hadithno{5499}\hadithtrans{Jabir reported that Allah's Messenger (ﷺ) forbade that a man should eat with the left hand or walk with one sandal or wrap himself completely leaving no opening for the arms (to draw out) or support himself when sitting with a single garment wrapped round his knees which may expose his private parts}}
\hadithdefcmd{muslim}{5500}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا انْقَطَعَ شِسْعُ أَحَدِكُمْ - أَوْ مَنِ انْقَطَعَ شِسْعُ نَعْلِهِ - فَلاَ يَمْشِ فِي نَعْلٍ وَاحِدَةٍ حَتَّى يُصْلِحَ شِسْعَهُ وَلاَ يَمْشِ فِي خُفٍّ وَاحِدٍ وَلاَ يَأْكُلْ بِشِمَالِهِ وَلاَ يَحْتَبِي بِالثَّوْبِ الْوَاحِدِ وَلاَ يَلْتَحِفِ الصَّمَّاءَ ‏"‏ ‏.‏\hadithno{5500}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:When the thong of the shoe of any one of you is cut off. he should not walk with one sandal until he has got the thong repaired, and he should not walk with one shoe and he should not eat with his left hand and should not wrap his cloth round his knees or wrap himself completely leaving no room for the arms}}
\hadithdefcmd{muslim}{5501}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ اشْتِمَالِ الصَّمَّاءِ وَالاِحْتِبَاءِ فِي ثَوْبٍ وَاحِدٍ وَأَنْ يَرْفَعَ الرَّجُلُ إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى وَهُوَ مُسْتَلْقٍ عَلَى ظَهْرِهِ ‏.‏\hadithno{5501}\hadithtrans{Jabir reported that Allah's Messenger (ﷺ) forbade the wrapping of oneself completely leaving no room for the arm and supporting oneself when sitting with a single garment wrapped round one's knees and a person raising one of his feet and placing it on the other while lying on his back}}
\hadithdefcmd{muslim}{5502}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ حَاتِمٍ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ، حَاتِمٍ حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ، اللَّهِ يُحَدِّثُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَمْشِ فِي نَعْلٍ وَاحِدٍ وَلاَ تَحْتَبِ فِي إِزَارٍ وَاحِدٍ وَلاَ تَأْكُلْ بِشِمَالِكَ وَلاَ تَشْتَمِلِ الصَّمَّاءَ وَلاَ تَضَعْ إِحْدَى رِجْلَيْكَ عَلَى الأُخْرَى إِذَا اسْتَلْقَيْتَ ‏"‏ ‏.‏\hadithno{5502}\hadithtrans{Jabir. b. Abdullah reported Allah's Messenger (ﷺ) as saying:Do not walk in one sandal and do not wrap the lower garment round your knees and do not eat with your left hand and do not wrap yourself completely leaving no room for the arms (to draw out) and do not place one of your feet upon the other while lying on your back}}
\hadithdefcmd{muslim}{5503}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنِي عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ الأَخْنَسِ - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَسْتَلْقِيَنَّ أَحَدُكُمْ ثُمَّ يَضَعُ إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى ‏"‏ ‏.‏\hadithno{5503}\hadithtrans{Jalbir b. Abdullah reported Allah's Messenger (ﷺ) as saying:None of you should lie on his back and place one of his feet upon the other}}
\hadithdefcmd{muslim}{5504}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم مُسْتَلْقِيًا فِي الْمَسْجِدِ وَاضِعًا إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى ‏.‏\hadithno{5504}\hadithtrans{Abbad b. Tamim reported from his uncle that he saw Allah's Messenger (ﷺ) lying in the mosque and placing his one foot upon the other}}
\hadithdefcmd{muslim}{5505}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَابْنُ نُمَيْرٍ وَزُهَيْرُ بْنُ حَرْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5505}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitter}}
\hadithdefcmd{muslim}{5506}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو الرَّبِيعِ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ، بْنُ زَيْدٍ وَقَالَ الآخَرَانِ حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ التَّزَعْفُرِ ‏.‏ قَالَ قُتَيْبَةُ قَالَ حَمَّادٌ يَعْنِي لِلرِّجَالِ ‏.‏\hadithno{5506}\hadithtrans{Anas b. Malik reported that Allah's Apostle (may peace he upon him) forbade dyeing (one's cloth or hair) in saffron. Hammad said that it pertains to men only}}
\hadithdefcmd{muslim}{5507}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَتَزَعْفَرَ الرَّجُلُ ‏.‏\hadithno{5507}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) forbade that a person should (wear) clothes dyed in saffron}}
\hadithdefcmd{muslim}{5508}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أُتِيَ بِأَبِي قُحَافَةَ أَوْ جَاءَ عَامَ الْفَتْحِ أَوْ يَوْمَ الْفَتْحِ وَرَأْسُهُ وَلِحْيَتُهُ مِثْلُ الثَّغَامِ أَوِ الثَّغَامَةِ فَأَمَرَ أَوْ فَأُمِرَ بِهِ إِلَى نِسَائِهِ قَالَ ‏ "‏ غَيِّرُوا هَذَا بِشَىْءٍ ‏"‏ ‏.‏\hadithno{5508}\hadithtrans{Jabir reported that when Abu Qubafa (father of Abu Bakr) came in the yeu of Victory or on the Day of Victory (to the Prophet to pledge his allegiance to him) his head and his beard were white like hyssop. He (the Holy Prophet) commaded or the women were commanded by him that they should change this with something (that the colour of his hair should be changed)}}
\hadithdefcmd{muslim}{5509}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أُتِيَ بِأَبِي قُحَافَةَ يَوْمَ فَتْحِ مَكَّةَ وَرَأْسُهُ وَلِحْيَتُهُ كَالثَّغَامَةِ بَيَاضًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَيِّرُوا هَذَا بِشَىْءٍ وَاجْتَنِبُوا السَّوَادَ ‏"‏ ‏.‏\hadithno{5509}\hadithtrans{Jabir b. 'Abdullah reported that Abu Qubafa was led (to the andience of the Holy Prophet) on the day of the Conquest of Mecca and his head and beard were white like hyssop, whereupon Allah's Messenger (ﷺ) said:Change it with something but avoid black}}
\hadithdefcmd{muslim}{5510}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، وَسُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْيَهُودَ وَالنَّصَارَى لاَ يَصْبُغُونَ فَخَالِفُوهُمْ ‏"‏ ‏.‏\hadithno{5510}\hadithtrans{Abu Horaira reported Allah's Messenger (ﷺ) as saying:The Jews and the Christians do not dye (their hair), so oppose them}}
\hadithdefcmd{muslim}{5511}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ، الرَّحْمَنِ عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ وَاعَدَ رَسُولَ اللَّهِ صلى الله عليه وسلم جِبْرِيلُ عَلَيْهِ السَّلاَمُ فِي سَاعَةٍ يَأْتِيهِ فِيهَا فَجَاءَتْ تِلْكَ السَّاعَةُ وَلَمْ يَأْتِهِ وَفِي يَدِهِ عَصًا فَأَلْقَاهَا مِنْ يَدِهِ وَقَالَ ‏"‏ مَا يُخْلِفُ اللَّهُ وَعْدَهُ وَلاَ رُسُلُهُ ‏"‏ ‏.‏ ثُمَّ الْتَفَتَ فَإِذَا جِرْوُ كَلْبٍ تَحْتَ سَرِيرِهِ فَقَالَ ‏"‏ يَا عَائِشَةُ مَتَى دَخَلَ هَذَا الْكَلْبُ هَا هُنَا ‏"‏ ‏.‏ فَقَالَتْ وَاللَّهِ مَا دَرَيْتُ ‏.‏ فَأَمَرَ بِهِ فَأُخْرِجَ فَجَاءَ جِبْرِيلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَاعَدْتَنِي فَجَلَسْتُ لَكَ فَلَمْ تَأْتِ ‏"‏ ‏.‏ فَقَالَ مَنَعَنِي الْكَلْبُ الَّذِي كَانَ فِي بَيْتِكَ إِنَّا لاَ نَدْخُلُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏.‏\hadithno{5511}\hadithtrans{A'isha reported that Gabriel (peace be upon him) made a promise with Allah's Messenger (ﷺ) to come at a definite hour; that hour came but he did not visit him. And there was in his hand (in the hand of Allah's Apostle) a staff. He threw it from his hand and said:Never has Allah or His messengers (angels) ever broken their promise. Then he cast a glance (and by chance) found a puppy under his cot and said: 'A'isha, when did this dog enter here? She said: By Allah, I don't know He then commanded and it was turned out. Then Gabriel came and Allah's Messenger (ﷺ) said to him: You promised me and I waited for you, but you did not come, whereupon he said: It was the dog in your house which prevented me (to come), for we (angels) do not enter a house in which there is a dog or a picture}}
\hadithdefcmd{muslim}{5512}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا الْمَخْزُومِيُّ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَبِي، حَازِمٍ بِهَذَا الإِسْنَادِ أَنَّ جِبْرِيلَ، وَعَدَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَأْتِيَهُ ‏.‏ فَذَكَرَ الْحَدِيثَ وَلَمْ يُطَوِّلْهُ كَتَطْوِيلِ ابْنِ أَبِي حَازِمٍ ‏.‏\hadithno{5512}\hadithtrans{This hadith has been narrated on the authority of Abu Hazim with the same chain of transmitters that Gabriel had promised Allah's Messenger (ﷺ) that he would come; the rest of the hadith is the same, but it is not so lengthy as the other one}}
\hadithdefcmd{muslim}{5513}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ السَّبَّاقِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، قَالَ أَخْبَرَتْنِي مَيْمُونَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَصْبَحَ يَوْمًا وَاجِمًا فَقَالَتْ مَيْمُونَةُ يَا رَسُولَ اللَّهِ لَقَدِ اسْتَنْكَرْتُ هَيْئَتَكَ مُنْذُ الْيَوْمِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ جِبْرِيلَ كَانَ وَعَدَنِي أَنْ يَلْقَانِي اللَّيْلَةَ فَلَمْ يَلْقَنِي أَمَ وَاللَّهِ مَا أَخْلَفَنِي ‏"‏ ‏.‏ قَالَ فَظَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَهُ ذَلِكَ عَلَى ذَلِكَ ثُمَّ وَقَعَ فِي نَفْسِهِ جِرْوُ كَلْبٍ تَحْتَ فُسْطَاطٍ لَنَا فَأَمَرَ بِهِ فَأُخْرِجَ ثُمَّ أَخَذَ بِيَدِهِ مَاءً فَنَضَحَ مَكَانَهُ فَلَمَّا أَمْسَى لَقِيَهُ جِبْرِيلُ فَقَالَ لَهُ ‏"‏ قَدْ كُنْتَ وَعَدْتَنِي أَنْ تَلْقَانِي الْبَارِحَةَ ‏"‏ ‏.‏ قَالَ أَجَلْ وَلَكِنَّا لاَ نَدْخُلُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏.‏ فَأَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ فَأَمَرَ بِقَتْلِ الْكِلاَبِ حَتَّى إِنَّهُ يَأْمُرُ بِقَتْلِ كَلْبِ الْحَائِطِ الصَّغِيرِ وَيَتْرُكُ كَلْبَ الْحَائِطِ الْكَبِيرِ ‏.‏\hadithno{5513}\hadithtrans{Maimuna reported that one morning Allah's Messenger (ﷺ) was silent with grief. Maimuna said:Allah's Messenger, I find a change in your mood today. Allah's Messenger (ﷺ) said: Gabriel had promised me that he would meet me tonight, but he did not meet me. By Allah, he never broke his promises, and Allah's Messenger (ﷺ) spent the day in this sad (mood). Then it occurred to him that there had been a puppy under their cot. He commanded and it was turned out. He then took some water in his hand and sprinkled it at that place. When it was evening Gabriel met him and he said to him: you promised me that you would meet me the previous night. He said: Yes, but we do not enter a house in which there is a dog or a picture. Then on that very morning he commanded the killing of the dogs until he announced that the dog kept for the orchards should also be killed, but he spared the dog meant for the protection of extensive fields (or big gardens)}}
\hadithdefcmd{muslim}{5514}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ قَالَ يَحْيَى وَإِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ، اللَّهِ عَنِ ابْنِ عَبَّاسٍ، عَنْ أَبِي طَلْحَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏"‏ ‏.‏\hadithno{5514}\hadithtrans{Abu Talha reported Allah's Apostle (ﷺ) having said:Angels do not enter a house in which there is a dog or a picture}}
\hadithdefcmd{muslim}{5515}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ سَمِعْتُ أَبَا طَلْحَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏"‏ ‏.‏\hadithno{5515}\hadithtrans{Abu Talha reported:I heard Allah's Messenger (ﷺ) as saying: Angels do not enter the house in which there is a dog or a statue}}
\hadithdefcmd{muslim}{5516}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ يُونُسَ وَذِكْرِهِ الأَخْبَارَ فِي الإِسْنَادِ ‏.‏\hadithno{5516}\hadithtrans{This hadith has been reported on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{5517}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ، عَنْ أَبِي طَلْحَةَ، صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ صُورَةٌ ‏"‏ ‏.‏ قَالَ بُسْرٌ ثُمَّ اشْتَكَى زَيْدٌ بَعْدُ فَعُدْنَاهُ فَإِذَا عَلَى بَابِهِ سِتْرٌ فِيهِ صُورَةٌ - قَالَ - فَقُلْتُ لِعُبَيْدِ اللَّهِ الْخَوْلاَنِيِّ رَبِيبِ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَلَمْ يُخْبِرْنَا زَيْدٌ عَنِ الصُّوَرِ يَوْمَ الأَوَّلِ فَقَالَ عُبَيْدُ اللَّهِ أَلَمْ تَسْمَعْهُ حِينَ قَالَ إِلاَّ رَقْمًا فِي ثَوْبٍ ‏.‏\hadithno{5517}\hadithtrans{Abu Tilha, the Companion of Allah's Messenger (ﷺ), reported Allah's Messenger (ﷺ) having said:Verily, angels do not enter the house in which there is a picture. Busr reported: Zaid fell ill and we went to inquire after his health and (found) that there was hanging at his door a curtain with a picture on it. I said to 'Ubaidullah Khaulani who had been under the patronage of Maimuna, the wife of Allah's Apostle (ﷺ): Did not Zaid himself inform us before about (the Holy Prophet's command pertaining to the pictures), whereupon 'Ubaidullah said: Did you not hear when he said:" Except the prints on the cloth"?}}
\hadithdefcmd{muslim}{5518}{حَدَّثَنَا أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ بُكَيْرَ بْنَ، الأَشَجِّ حَدَّثَهُ أَنَّ بُسْرَ بْنَ سَعِيدٍ حَدَّثَهُ أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ حَدَّثَهُ وَمَعَ، بُسْرٍ عُبَيْدُ اللَّهِ الْخَوْلاَنِيُّ أَنَّ أَبَا طَلْحَةَ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ صُورَةٌ ‏"‏ ‏.‏ قَالَ بُسْرٌ فَمَرِضَ زَيْدُ بْنُ خَالِدٍ فَعُدْنَاهُ فَإِذَا نَحْنُ فِي بَيْتِهِ بِسِتْرٍ فِيهِ تَصَاوِيرُ فَقُلْتُ لِعُبَيْدِ اللَّهِ الْخَوْلاَنِيِّ أَلَمْ يُحَدِّثْنَا فِي التَّصَاوِيرِ قَالَ إِنَّهُ قَالَ إِلاَّ رَقْمًا فِي ثَوْبٍ أَلَمْ تَسْمَعْهُ قُلْتُ لاَ ‏.‏ قَالَ بَلَى قَدْ ذَكَرَ ذَلِكَ ‏.‏\hadithno{5518}\hadithtrans{Abu Talha reported that Allah's Messenger (ﷺ) said:Angels do not enter a house in which there is a picture. Busr said: Zaid b. Khalid fell sick and we visited him to inquire after his health. As we were in his house (we saw) a curtain having pictures on it. I said to 'Ubaidullah Khaulani: Did he not narrate to us (the Holy Prophet's command pertaining to pictures)? Thereupon he said: He in fact did that (but he also said): Except the prints upon the cloth. Did you not hear this? I said: No, whereupon He said: He had in fact made a mention of this}}
\hadithdefcmd{muslim}{5520}{حَدَّثَنَا إِسْح��اقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ سَعِيدِ، بْنِ يَسَارٍ أَبِي الْحُبَابِ مَوْلَى بَنِي النَّجَّارِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، عَنْ أَبِي طَلْحَةَ الأَنْصَارِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ تَمَاثِيلُ ‏"‏ ‏.‏ قَالَ فَأَتَيْتُ عَائِشَةَ فَقُلْتُ إِنَّ هَذَا يُخْبِرُنِي أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ تَمَاثِيلُ ‏"‏ ‏.‏ فَهَلْ سَمِعْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ ذَلِكَ فَقَالَتْ لاَ وَلَكِنْ سَأُحَدِّثُكُمْ مَا رَأَيْتُهُ فَعَلَ رَأَيْتُهُ خَرَجَ فِي غَزَاتِهِ فَأَخَذْتُ نَمَطًا فَسَتَرْتُهُ عَلَى الْبَابِ فَلَمَّا قَدِمَ فَرَأَى النَّمَطَ عَرَفْتُ الْكَرَاهِيَةَ فِي وَجْهِهِ فَجَذَبَهُ حَتَّى هَتَكَهُ أَوْ قَطَعَهُ وَقَالَ ‏"‏ إِنَّ اللَّهَ لَمْ يَأْمُرْنَا أَنْ نَكْسُوَ الْحِجَارَةَ وَالطِّينَ ‏"‏ ‏.‏ قَالَتْ فَقَطَعْنَا مِنْهُ وِسَادَتَيْنِ وَحَشَوْتُهُمَا لِيفًا فَلَمْ يَعِبْ ذَلِكَ عَلَىَّ ‏.‏\hadithno{5520}\hadithtrans{Abu Talha Ansari reported Allah's Messenger (ﷺ) as saying:Angels do not enter the house in which there is a picture or portraits. I came to 'A'isha and said to her: This is a news that I have received that Allah's Apostle (ﷺ) had said: Angels do not enter the house in which there is a picture or a dog, (and further added) whether she had heard Allah's Messenger (ﷺ) making a mention of it. She said: No (I did not hear this myself), but I narrate to you what I saw him doing. I bear testimony to the fact that he (the Holy Prophet) set out for an expedition. I took a carpet and screened the door with it. When he (the Holy Prophet) came back he saw that carpet and I perceived signs of disapproval on his face. He pulled it until it was torn or it was cut (into pieces) and he said: God has not commanded us to clothe stones and clay. We cut it (the curtain) and prepared two pillowa out of it by stuffing them with the fibre of date-palms and he (the Holy Prophet) did not find fault with it}}
\hadithdefcmd{muslim}{5523}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ سَفَرٍ وَقَدْ سَتَّرْتُ عَلَى بَابِي دُرْنُوكًا فِيهِ الْخَيْلُ ذَوَاتُ الأَجْنِحَةِ فَأَمَرَنِي فَنَزَعْتُهُ ‏.‏\hadithno{5523}\hadithtrans{A'isha reported:Allah's Messenger (ﷺ) came back from the journey and I had screened my door with a curtain having portraits of winged horses upon it. He commanded me and I pulled it away}}
\hadithdefcmd{muslim}{5524}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، ح وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، بِهَذَا الإِسْنَادِ وَلَيْسَ فِي حَدِيثِ عَبْدَةَ قَدِمَ مِنْ سَفَرٍ ‏.‏\hadithno{5524}\hadithtrans{This hadith has been narrpted on the authority of Waki' with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5525}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنِ الْقَاسِمِ، بْنِ مُحَمَّدٍ عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مُتَسَتِّرَةٌ بِقِرَامٍ فِيهِ صُورَةٌ فَتَلَوَّنَ وَجْهُهُ ثُمَّ تَنَاوَلَ السِّتْرَ فَهَتَكَهُ ثُمَّ قَالَ ‏ "‏ إِنَّ مِنْ أَشَدِّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ الَّذِينَ يُشَبِّهُونَ بِخَلْقِ اللَّهِ ‏"‏ ‏.‏\hadithno{5525}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) entered (my apartment) and I had hung (on the door of my apartment) a thin curtain having pictures on it. The colour of his face underwent a change. He then took hold of that curtain and tore it and then said:The most grievous torfnent for the people on the Day of Resurrection would be for those who try to imitate Allah in the act of creation}}
\hadithdefcmd{muslim}{5526}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّ عَائِشَةَ، حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَيْهَا ‏.‏ بِمِثْلِ حَدِيثِ إِبْرَاهِيمَ بْنِ سَعْدٍ غَيْرَ أَنَّهُ قَالَ ثُمَّ أَهْوَى إِلَى الْقِرَامِ فَهَتَكَهُ بِيَدِهِ ‏.‏\hadithno{5526}\hadithtrans{This hadith has been narrated on the authority of A'isha through another chain of transmitters but with a slight variation of wording (and the variation is that the narrator is reported to have said):He (the Holy Prophet) inclined towards that curtain and tore it with his hand}}
\hadithdefcmd{muslim}{5527}{حَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِهِمَا ‏ "‏ إِنَّ أَشَدَّ النَّاسِ عَذَابًا ‏"‏ ‏.‏ لَمْ يَذْكُرَا مِنْ ‏.‏\hadithno{5527}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5528}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - وَاللَّفْظُ لِزُهَيْرٍ - حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ عَائِشَةَ، تَقُولُ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ سَتَرْتُ سَهْوَةً لِي بِقِرَامٍ فِيهِ تَمَاثِيلُ فَلَمَّا رَآهُ هَتَكَهُ وَتَلَوَّنَ وَجْهُهُ وَقَالَ ‏ "‏ يَا عَائِشَةُ أَشَدُّ النَّاسِ عَذَابًا عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ الَّذِينَ يُضَاهُونَ بِخَلْقِ اللَّهِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَقَطَعْنَاهُ فَجَعَلْنَا مِنْهُ وِسَادَةً أَوْ وِسَادَتَيْنِ ‏.‏\hadithno{5528}\hadithtrans{A'isha reported:Allah's Messenger (ﷺ) visited me. and I had a shelf with a thin cloth curtain hangin. over it and on which there were portraits. No sooner did he see it than he tore it and the colour of his face underwent a change and he said: A'isha, the most grievous torment from the Hand of Allah on the Day of Resurrection would be for those who imitate (Allah) in the act of His creation. A'isha said: We tore it into pieces and made a cushion or two cushions out of that}}
\hadithdefcmd{muslim}{5529}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ الْقَاسِمِ قَالَ سَمِعْتُ الْقَاسِمَ، يُحَدِّثُ عَنْ عَائِشَةَ، أَنَّهُ كَانَ لَهَا ثَوْبٌ فِيهِ تَصَاوِيرُ مَمْدُودٌ إِلَى سَهْوَةٍ فَكَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي إِلَيْهِ فَقَالَ ‏ "‏ أَخِّرِيهِ عَنِّي ‏"‏ ‏.‏ قَالَتْ فَأَخَّرْتُهُ فَجَعَلْتُهُ وَسَائِدَ ‏.‏\hadithno{5529}\hadithtrans{A'isha reported she had a cloth havinc, pictures upon it and it was hanging upon the shelf and Allah's Messenger (ﷺ) said:Take it (away) from me (from my sight), so I removed it and made cushions from that}}
\hadithdefcmd{muslim}{5530}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعُقْبَةُ بْنُ مُكْرَمٍ، عَنْ سَعِيدِ بْنِ عَامِرٍ، ح وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبْرَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، جَمِيعًا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5530}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{5531}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَىَّ وَقَدْ سَتَرْتُ نَمَطًا فِيهِ تَصَاوِيرُ فَنَحَّاهُ فَاتَّخَذْتُ مِنْهُ وِسَادَتَيْنِ ‏.‏\hadithno{5531}\hadithtrans{A'isha reported:Allah's Apostle (ﷺ) visited me when I had screened (my door) with a carpet having pictures on it. He removed it and we made cushions out of that}}
\hadithdefcmd{muslim}{5532}{وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا عَمْرُو بْنُ الْحَارِثِ، أَنَّ بُكَيْرًا، حَدَّثَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ حَدَّثَهُ أَنَّ أَبَاهُ حَدَّثَهُ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا نَصَبَتْ سِتْرًا فِيهِ تَصَاوِيرُ فَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَزَعَهُ قَالَتْ فَقَطَعْتُهُ وِسَادَتَيْنِ ‏.‏ فَقَالَ رَجُلٌ فِي الْمَجْلِسِ حِينَئِذٍ يُقَالُ لَهُ رَبِيعَةُ بْنُ عَطَاءٍ مَوْلَى بَنِي زُهْرَةَ أَفَمَا سَمِعْتَ أَبَا مُحَمَّدٍ يَذْكُرُ أَنَّ عَائِشَةَ قَالَتْ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرْتَفِقُ عَلَيْهِمَا قَالَ ابْنُ الْقَاسِمِ لاَ ‏.‏ قَالَ لَكِنِّي قَدْ سَمِعْتُهُ ‏.‏ يُرِيدُ الْقَاسِمَ بْنَ مُحَمَّدٍ ‏.‏\hadithno{5532}\hadithtrans{A'isha, the wife of Allah's Messenger (ﷺ), reported that she had hung a curtain which had pictures upon it. Allah's Messenger (ﷺ) entered (the room) and he pulled it. A'isha said:I then tore it and prepared two cushions out of that. A person who was then in that company and whose name was Rabi'a b. 'Ata, the freed slave of Banu Zuhra, asked: Did you hear Abu Mabammad making a mention of A'isha having stated that Allah's Messenger (ﷺ) used to recline upon them? lbn al-Qasim said: No, but I heard Qasim b. Muhammad saying so}}
\hadithdefcmd{muslim}{5533}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّهَا اشْتَرَتْ نُمْرَقَةً فِيهَا تَصَاوِيرُ فَلَمَّا رَآهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَامَ عَلَى الْبَابِ فَلَمْ يَدْخُلْ فَعَرَفْتُ أَوْ فَعُرِفَتْ فِي وَجْهِهِ الْكَرَاهِيَةُ فَقَالَتْ يَا رَسُولَ اللَّهِ أَتُوبُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ فَمَاذَا أَذْنَبْتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا بَالُ هَذِهِ النُّمْرُقَةِ ‏"‏ ‏.‏ فَقَالَتِ اشْتَرَيْتُهَا لَكَ تَقْعُدُ عَلَيْهَا وَتَوَسَّدُهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ يُعَذَّبُونَ وَيُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ الْبَيْتَ الَّذِي فِيهِ الصُّوَرُ لاَ تَدْخُلُهُ الْمَلاَئِكَةُ ‏"‏ ‏.‏\hadithno{5533}\hadithtrans{A'isha reported that she bought a carpet which had pictures on it. When Allah's Messenger (ﷺ) saw that, he stayed at the door and did not get in. I perceived or I was made to perceive upon his face signs of disgust. She said:Allah's Messenger, I offer repentance to Allah and His Messenger. (but tell me) what is the sin that I have committed. Thereupon Allah's Messenger (ﷺ) said: What is this carpet? She said: I bought it for you so that you might sit on it and take rest. Thereupon Allah's Messenger (ﷺ) said: The owners of these pictures would be tormented and they would be asked to bring to life what they tried to create. He then said: Angels do not enter the house in which there is a picture}}
\hadithdefcmd{muslim}{5534}{وَحَدَّثَنَاهُ قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الثَّقَفِيُّ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا أَبِي، عَنْ جَدِّي، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، حَدَّثَنَا أَبُو سَلَمَةَ الْخُزَاعِيُّ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ أَخِي، الْمَاجِشُونِ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، كُلُّهُمْ عَنْ نَافِعٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، بِهَذَا الْحَدِيثِ وَبَعْضُهُمْ أَتَمُّ حَدِيثًا لَهُ مِنْ بَعْضٍ ‏.‏ وَزَادَ فِي حَدِيثِ ابْنِ أَخِي الْمَاجِشُونِ قَالَتْ فَأَخَذْتُهُ فَجَعَلْتُهُ مِرْفَقَتَيْنِ فَكَانَ يَرْتَفِقُ بِهِمَا فِي الْبَيْتِ ‏.‏\hadithno{5534}\hadithtrans{This hadith has been narrated on the authority of A'isha through another chain of transmitters also. Some of the other ahadith narrated through other chains of transmitters are more complete and there is an addition in them (transmitted through other chains of transmitters). In the hadith transmitted on the authority of the nephew of Majishun she (A'isha) is reported to have said:I took it and prepared two cushions out of that and he (the Holy Prophet) used to recline against them in the house}}
\hadithdefcmd{muslim}{5535}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - جَمِيعًا عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِينَ يَصْنَعُونَ الصُّوَرَ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ يُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏ ‏.‏\hadithno{5535}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) having said:Those who paint pictures would be punished on the Day of Resurrection and it would be said to them: Breathe soul into what you have created}}
\hadithdefcmd{muslim}{5536}{حَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا الثَّقَفِيُّ، كُلُّهُمْ عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{5536}\hadithtrans{Ibn 'Umar reported a hadith like this through another chain of transmitters}}
\hadithdefcmd{muslim}{5537}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنِي أَبُو سَعِيدٍ، الأَشَجُّ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَشَدَّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ الْمُصَوِّرُونَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ الأَشَجُّ إِنَّ ‏.‏\hadithno{5537}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:Verity the most grievously tormented people on the Day of Resurrection would be the painters of pictures. Ashajj (one of the narrators) in the hadith narrated by him did not make mention of the word" verity}}
\hadithdefcmd{muslim}{5538}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ كُلُّهُمْ عَنْ أَبِي مُعَاوِيَةَ، ح وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي رِوَايَةِ يَحْيَى وَأَبِي كُرَيْبٍ عَنْ أَبِي مُعَاوِيَةَ، ‏ "‏ إِنَّ مِنْ أَشَدِّ أَهْلِ النَّارِ يَوْمَ الْقِيَامَةِ عَذَابًا الْمُصَوِّرُونَ ‏"‏ ‏.‏ وَحَدِيثُ سُفْيَانَ كَحَدِيثِ وَكِيعٍ ‏.‏\hadithno{5538}\hadithtrans{This hadith has been reported on the authority of Abu Mu`awiya through another chain of transmitters (and the words are):"Verily, the most grievously tormented people amongst the denizens of Hell on the Day of Resurrection would be the painters of pictures." The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5546}{حَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصْحَبُ الْمَلاَئِكَةُ رُفْقَةً فِيهَا كَلْبٌ وَلاَ جَرَسٌ ‏"‏ ‏.‏\hadithno{5546}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Angels do not accompany the travellers who have with them a dog and a bell}}
\hadithdefcmd{muslim}{5547}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - كِلاَهُمَا عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5547}\hadithtrans{This hadith has been reported on the authority of Suhail with the same chain of transmitters}}
\hadithdefcmd{muslim}{5548}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْجَرَسُ مَزَامِيرُ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{5548}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The bell is the musical instrument of the Satan}}
\hadithdefcmd{muslim}{5549}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ، بْنِ تَمِيمٍ أَنَّ أَبَا بَشِيرٍ الأَنْصَارِيَّ، أَخْبَرَهُ أَنَّهُ، كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ - قَالَ - فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَسُولاً - قَالَ عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ حَسِبْتُ أَنَّهُ قَالَ وَالنَّاسُ فِي مَبِيتِهِمْ - ‏ "‏ لاَ يَبْقَيَنَّ فِي رَقَبَةِ بَعِيرٍ قِلاَدَةٌ مِنْ وَتَرٍ أَوْ قِلاَدَةٌ إِلاَّ قُطِعَتْ ‏"‏ ‏.‏ قَالَ مَالِكٌ أُرَى ذَلِكَ مِنَ الْعَيْنِ ‏.‏\hadithno{5549}\hadithtrans{Abu Bashir Ansari reported that he had had (the opportunity of accompanying Allah's Messenger (ﷺ) in some of his journeys. Allah's Messenger (ﷺ) sent one of his messengers 'Abdullah b Abi Bakr said:I think he said (these words) when the people were at the places of rest: No necklace of strings be left on the necks of the camels or the necklace kept unbroken. Imam Malik said: To my mind (this practice) of wearing necklace round the necks of camels or animals was because of the fact that they (wanted to save them) from the influence of the evil eye}}
\hadithdefcmd{muslim}{5550}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الضَّرْبِ فِي الْوَجْهِ وَعَنِ الْوَسْمِ فِي الْوَجْهِ ‏.‏\hadithno{5550}\hadithtrans{Jabir reported that Allah's Messenger (ﷺ) forbade (the animals to be beaten) on the face or cauterisation on the face}}
\hadithdefcmd{muslim}{5551}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، ‏.‏ كِلاَهُمَا عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ، بْنَ عَبْدِ اللَّهِ يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{5551}\hadithtrans{This hadith has been reported on the authority of Jabir b. 'Abdullah through another chain of transmitters}}
\hadithdefcmd{muslim}{5552}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ عَلَيْهِ حِمَارٌ قَدْ وُسِمَ فِي وَجْهِهِ فَقَالَ ‏ "‏ لَعَنَ اللَّهُ الَّذِي وَسَمَهُ ‏"‏ ‏.‏\hadithno{5552}\hadithtrans{Jabir reported that there happened to pass before Allah's Apostle (ﷺ) an ass the face of which had been cauterised, whereupon he said:Allah has cursed one who has cauterised it (on the face)}}
\hadithdefcmd{muslim}{5553}{حَدَّثَنَا أَحْمَدُ بْنُ عِيسَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ يَزِيدَ، بْنِ أَبِي حَبِيبٍ أَنَّ نَاعِمًا أَبَا عَبْدِ اللَّهِ، مَوْلَى أُمِّ سَلَمَةَ حَدَّثَهُ أَنَّهُ، سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ وَرَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم حِمَارًا مَوْسُومَ الْوَجْهِ فَأَنْكَرَ ذَلِكَ قَالَ فَوَاللَّهِ لاَ أَسِمُهُ إِلاَّ فِي أَقْصَى شَىْءٍ مِنَ الْوَجْهِ ‏.‏ فَأَمَرَ بِحِمَارٍ لَهُ فَكُوِيَ فِي جَاعِرَتَيْهِ فَهُوَ أَوَّلُ مَنْ كَوَى الْجَاعِرَتَيْنِ ‏.‏\hadithno{5553}\hadithtrans{Ibn Abbas reported that Allah's Messenger (ﷺ) saw an ass which had been cauterised on the face. He disapproved of it saying:By Allah, I do not cauterise (the animal) but on a part at a distance from the face, and commanded (for the cauterisation) of his ass and it was cauterised on the buttocks and he was the first to cauterise on the buttocks}}
\hadithdefcmd{muslim}{5554}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، قَالَ لَمَّا وَلَدَتْ أُمُّ سُلَيْمٍ قَالَتْ لِي يَا أَنَسُ انْظُرْ هَذَا الْغُلاَمَ فَلاَ يُصِيبَنَّ شَيْئًا حَتَّى تَغْدُوَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم يُحَنِّكُهُ ‏.‏ قَالَ فَغَدَوْتُ فَإِذَا هُوَ فِي الْحَائِطِ وَعَلَيْهِ خَمِيصَةٌ جَوْنِيَّةٌ وَهُوَ يَسِمُ الظَّهْرَ الَّذِي قَدِمَ عَلَيْهِ فِي الْفَتْحِ ‏.‏\hadithno{5554}\hadithtrans{Anas reported that Umm Sulaim gave birth to a child. She said to him:Anas, see that nothing is given to this child until he is brought to Allah's Apostle (ﷺ) in the morning, so that he should chew some dates and touch his palate with it. I went to him in the morning and he was in the garden at that time having the mantle of Jauniyya over him and he was bus in cauterising (the camels) which had been brought to him (as spoils of war) in victory (over the enemy)}}
\hadithdefcmd{muslim}{5555}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، قَالَ سَمِعْتُ أَنَسًا، يُحَدِّثُ أَنَّ أُمَّهُ، حِينَ وَلَدَتِ انْطَلَقُوا بِالصَّبِيِّ إِلَى النَّبِيِّ صلى الله عليه وسلم يُحَنِّكُهُ قَالَ فَإِذَا النَّبِيُّ صلى الله عليه وسلم فِي مِرْبَدٍ يَسِمُ غَنَمًا ‏.‏ قَالَ شُعْبَةُ وَأَكْثَرُ عِلْمِي أَنَّهُ قَالَ فِي آذَانِهَا ‏.‏\hadithno{5555}\hadithtrans{Anas reported that when his mother gave birth to a child they brought that child to Allah's Messenger (ﷺ) so that he might chew some dates and touch his palate with them. and Allah's Apostle (ﷺ) was at that time in the fold busy in cauterising the animals Shu'ba said:So far as I know (he was cauterising) their ears}}
\hadithdefcmd{muslim}{5558}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ إِسْحَاقَ، بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَيْتُ فِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم الْمِيسَمَ وَهُوَ يَسِمُ إِبِلَ الصَّدَقَةِ ‏.‏\hadithno{5558}\hadithtrans{Anas b. Malik reported:I saw in the hand of Allah's Messenger (ﷺ) an instrument for cauterisation and he was cauterising the caracia collected as Zakat}}
\hadithdefcmd{muslim}{5559}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنِي يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي عُمَرُ بْنُ نَافِعٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْقَزَعِ ‏.‏ قَالَ قُلْتُ لِنَافِعٍ وَمَا الْقَزَعُ قَالَ يُحْلَقُ بَعْضُ رَأْسِ الصَّبِيِّ وَيُتْرَكُ بَعْضٌ ‏.‏\hadithno{5559}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) forbade Qaza. I said to Nafi:What is Qaza'? He said: This means having a part of a boy's head shaved and leaving a part unshaven}}
\hadithdefcmd{muslim}{5560}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏ وَجَعَلَ التَّفْسِيرَ فِي حَدِيثِ أَبِي أُسَامَةَ مِنْ قَوْلِ عُبَيْدِ اللَّهِ ‏.‏\hadithno{5560}\hadithtrans{This hadith has been reported on the authority of 'Ubaidullah with the same chain of transmitters. and the exposition of Qaza' is the same as that of Abu Usama}}
\hadithdefcmd{muslim}{5561}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عُثْمَانُ بْنُ عُثْمَانَ الْغَطَفَانِيُّ، حَدَّثَنَا عُمَرُ بْنُ نَافِعٍ، ح وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامٍ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، عَنْ عُمَرَ بْنِ، نَافِعٍ بِإِسْنَادِ عُبَيْدِ اللَّهِ ‏.‏ مِثْلَهُ وَأَلْحَقَا التَّفْسِيرَ فِي الْحَدِيثِ ‏.‏\hadithno{5561}\hadithtrans{This hadith has been narrated on the authority of 'Umar b. Nafi' with the same chain of transmitters and Muhammad b. Muthanna as well as 'Umar b. Nafi have given the same exposition (of the word Qaza') in their narration}}
\hadithdefcmd{muslim}{5562}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَحَجَّاجُ بْنُ الشَّاعِرِ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ عَبْدِ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا أَبُو جَعْفَرٍ الدَّارِمِيُّ، حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ، زَيْدٍ عَنْ عَبْدِ الرَّحْمَنِ السَّرَّاجِ، كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِذَلِكَ ‏.‏\hadithno{5562}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{5563}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنِي حَفْصُ بْنُ مَيْسَرَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ، بْنِ يَسَارٍ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالْجُلُوسَ فِي الطُّرُقَاتِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا لَنَا بُدٌّ مِنْ مَجَالِسِنَا نَتَحَدَّثُ فِيهَا ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِذَا أَبَيْتُمْ إِلاَّ الْمَجْلِسَ فَأَعْطُوا الطَّرِيقَ حَقَّهُ ‏"‏ ‏.‏ قَالُوا وَمَا حَقُّهُ قَالَ ‏"‏ غَضُّ الْبَصَرِ وَكَفُّ الأَذَى وَرَدُّ السَّلاَمِ وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏"‏ ‏.‏\hadithno{5563}\hadithtrans{Abu Sa'id Al-Khudri reported Allah's Apostle (ﷺ) as saying:Avoid sitting on the paths. They (his Companions) said: Allah's Messenger, there is no other help to it (but to sit there as we) hold our meetings and discuss matters there. Thereupon Allah's Messenger (ﷺ) said: If you have to sit at all, then fulfil the rights, of the path. They said: What are their rights? Thereupon he said: Keeping the eye downward (so that you may not stare at the women), refraining from doing some harm to the other and exchanging mutual greetings (saying as-Salamu 'Alaikum to one another) and commanding the good and forbidding the evil}}
\hadithdefcmd{muslim}{5564}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الْمَدَنِيُّ، ح وَحَدَّثَنَاهُ مُحَمَّدُ، بْنُ رَافِعٍ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا هِشَامٌ، - يَعْنِي ابْنَ سَعْدٍ - كِلاَهُمَا عَنْ زَيْدِ بْنِ، أَسْلَمَ بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5564}\hadithtrans{This hadith has been reported on the authority of Zaid b. Aslam with the same chain of transmitters}}
\hadithdefcmd{muslim}{5565}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ، الْمُنْذِرِ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ لِي ابْنَةً عُرَيِّسًا أَصَابَتْهَا حَصْبَةٌ فَتَمَرَّقَ شَعْرُهَا أَفَأَصِلُهُ فَقَالَ ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ ‏"‏ ‏.‏\hadithno{5565}\hadithtrans{Asma', daughter of Abu Bakr, reported that a woman came to Allah's Apostle (ﷺ) and said:I have a daughter who has been newly wedded. She had an attack of smallpox and thus her hair had fallen; should I add false hair to her head? Thereupon Allah's Messenger (ﷺ) said: Allah has cursed the woman who adds some false hair and the woman who asks for it}}
\hadithdefcmd{muslim}{5566}{حَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، ح وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، وَعَبْدَةُ ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، أَخْبَرَنَا أَسْوَدُ بْنُ عَامِرٍ، أَخْبَرَنَا شُعْبَةُ، كُلُّهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ أَبِي مُعَاوِيَةَ غَيْرَ أَنَّحَدِيثِهِمَا فَتَمَرَّطَ شَعْرُهَا ‏.‏\hadithno{5566}\hadithtrans{This hadith has been transmitted on the authority of Shu'ba with a slight variation of wording}}
\hadithdefcmd{muslim}{5567}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، أَخْبَرَنَا حَبَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مَنْصُورٌ، عَنْ أُمِّهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّ امْرَأَةً، أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ إِنِّي زَوَّجْتُ ابْنَتِي فَتَمَرَّقَ شَعْرُ رَأْسِهَا وَزَوْجُهَا يَسْتَحْسِنُهَا أَفَأَصِلُ يَا رَسُولَ اللَّهِ فَنَهَاهَا ‏.‏\hadithno{5567}\hadithtrans{Asma', daughter of Abu Bakr, reported that a woman came to Allah's Apostle (ﷺ) and said:I have married my daughter (whose) hair of head have fallen. Her spouse likes them (the long hair). Allah's Messenger (may add false hair to her head? He forbade her to do this)}}
\hadithdefcmd{muslim}{5568}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ، مُرَّةَ قَالَ سَمِعْتُ الْحَسَنَ بْنَ مُسْلِمٍ، يُحَدِّثُ عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، أَنَّ جَارِيَةً، مِنَ الأَنْصَارِ تَزَوَّجَتْ وَأَنَّهَا مَرِضَتْ فَتَمَرَّطَ شَعْرُهَا فَأَرَادُوا أَنْ يَصِلُوهُ فَسَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَلَعَنَ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ ‏.‏\hadithno{5568}\hadithtrans{A'isha reported that a girl of the Ansar who had fallen ill and had lost the hair was married. They (her relatives) thought of adding false hair (to her head). so they asked Allah's Messenger (ﷺ) about it, whereupon he cursed the woman who adds false hair and the woman who asks for it}}
\hadithdefcmd{muslim}{5573}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لإِسْحَاقَ - أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ اللَّهُ الْوَاشِمَاتِ وَالْمُسْتَوْشِمَاتِ وَالنَّامِصَاتِ وَالْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ الْمُغَيِّرَاتِ خَلْقَ اللَّهِ ‏.‏ قَالَ فَبَلَغَ ذَلِكَ امْرَأَةً مِنْ بَنِي أَسَدٍ يُقَالُ لَهَا أُمُّ يَعْقُوبَ وَكَانَتْ تَقْرَأُ الْقُرْآنَ فَأَتَتْهُ فَقَالَتْ مَا حَدِيثٌ بَلَغَنِي عَنْكَ أَنَّكَ لَعَنْتَ الْوَاشِمَاتِ وَالْمُسْتَوْشِمَاتِ وَالْمُتَنَمِّصَاتِ وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ الْمُغَيِّرَاتِ خَلْقَ اللَّهِ فَقَالَ عَبْدُ اللَّهِ وَمَا لِيَ لاَ أَلْعَنُ مَنْ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي كِتَابِ اللَّهِ فَقَالَتِ الْمَرْأَةُ لَقَدْ قَرَأْتُ مَا بَيْنَ لَوْحَىِ الْمُصْحَفِ فَمَا وَجَدْتُهُ ‏.‏ فَقَالَ لَئِنْ كُنْتِ قَرَأْتِيهِ لَقَدْ وَجَدْتِيهِ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَمَا آتَاكُمُ الرَّسُولُ فَخُذُوهُ وَمَا نَهَاكُمْ عَنْهُ فَانْتَهُوا‏\}‏ فَقَالَتِ الْمَرْأَةُ فَإِنِّي أَرَى شَيْئًا مِنْ هَذَا عَلَى امْرَأَتِكَ الآنَ ‏.‏ قَالَ اذْهَبِي فَانْظُرِي ‏.‏ قَالَ فَدَخَلَتْ عَلَى امْرَأَةِ عَبْدِ اللَّهِ فَلَمْ تَرَ شَيْئًا فَجَاءَتْ إِلَيْهِ فَقَالَتْ مَا رَأَيْتُ شَيْئًا ‏.‏ فَقَالَ أَمَا لَوْ كَانَ ذَلِكِ لَمْ نُجَامِعْهَا ‏.‏\hadithno{5573}\hadithtrans{Abdullah reported that Allah had cursed those women who tattooed and who have themselves tattooed, those who pluck hair from their faces and those who make spaces between their teeth for beautification changing what God has created. This news reached a woman of the tribe of Asad who was called Umm Ya'qub and she used to recite the Holy Qur'an. She came to him and said:What is this news that has reached me from you that you curse those women who tattooed and those women who have themselves tattooed, the women who pluck hair from their faces and who make spaces between their teeth for beautification changing what God has created? Thereupon 'Abdullah said: Should I not curse one upon whom Allah's Messenger (ﷺ) has invoked curse and that is in the Book also. Thereupon that woman said: I read the Qur'an from cover to cover, but I did not find that in it. whereupon he said: If you had read (thoroughly) you would have definitely found this in that (as) Allah, the Exalted and Glorious, has said:" What Allah's Messenger brings for you accept that and what he has forbidden you, refrain from that." That woman said: I find this thing in your wife even now. Thereupon he said: Go and see her. She reported: I went to the wife of 'Abdullah but found nothing of this sort in her. She came back to him and said: I have not seen anything. whereupon he said: Had there been anything like it in her, I would have never slept with her in the bed}}
\hadithdefcmd{muslim}{5574}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، وَهُوَ ابْنُ مَهْدِيٍّ حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا مُفَضَّلٌ، - وَهُوَ ابْنُ مُهَلْهَلٍ - كِلاَهُمَا عَنْ مَنْصُورٍ، فِي هَذَا الإِسْنَادِ ‏.‏ بِمَعْنَى حَدِيثِ جَرِيرٍ غَيْرَ أَنَّ فِي حَدِيثِ سُفْيَانَ الْوَاشِمَاتِ وَالْمُسْتَوْشِمَاتِ ‏.‏ وَفِي حَدِيثِ مُفَضَّلٍ الْوَاشِمَاتِ وَالْمَوْشُومَاتِ ‏.‏\hadithno{5574}\hadithtrans{This hadith has been reported on the authority of Mansur with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5575}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالُوا حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ ‏.‏ الْحَدِيثَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُجَرَّدًا عَنْ سَائِرِ الْقِصَّةِ، مِنْ ذِكْرِ أُمِّ يَعْقُوبَ ‏.‏\hadithno{5575}\hadithtrans{This hadith has been narrated on the authority of Mansur without the story pertaining to Umm Ya'qub}}
\hadithdefcmd{muslim}{5576}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرٌ، - يَعْنِي ابْنَ حَازِمٍ - حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{5576}\hadithtrans{This hadith has been transmitted on the authority of Abdullah}}
\hadithdefcmd{muslim}{5577}{وَحَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ زَجَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ تَصِلَ الْمَرْأَةُ بِرَأْسِهَا شَيْئًا ‏.‏\hadithno{5577}\hadithtrans{Jabir b. Abdullah reported that Allah's Apostle (ﷺ) reprimanded that a woman should add anything to her head (in the form of artificial hair)}}
\hadithdefcmd{muslim}{5578}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ، الرَّحْمَنِ بْنِ عَوْفٍ أَنَّهُ سَمِعَ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، عَامَ حَجَّ وَهُوَ عَلَى الْمِنْبَرِ وَتَنَاوَلَ قُصَّةً مِنْ شَعَرٍ كَانَتْ فِي يَدِ حَرَسِيٍّ يَقُولُ يَا أَهْلَ الْمَدِينَةِ أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ مِثْلِ هَذِهِ وَيَقُولُ ‏ "‏ إِنَّمَا هَلَكَتْ بَنُو إِسْرَائِيلَ حِينَ اتَّخَذَ هَذِهِ نِسَاؤُهُمْ ‏"‏ ‏.‏\hadithno{5578}\hadithtrans{Abd al-Rahman b. 'Auf said that he heard Mu'awiya b. Abi Sufyin during the season of Hajj, (saying) as he sat upon the pulpit holding a bunch of hair in his hand which was (previously) in the hand of his sentinel:O people of Medina, where are your scholars? I heard Allah's Messenger (ﷺ) forbidding this and saying: That the people of Bani Isra'il were ruined at the time when their women wore such hair}}
\hadithdefcmd{muslim}{5579}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ غَيْرَ أَنَّ فِي حَدِيثِ مَعْمَرٍ ‏ "‏ إِنَّمَا عُذِّبَ بَنُو إِسْرَائِيلَ ‏"‏ ‏.‏\hadithno{5579}\hadithtrans{This hadith has been transmitted on the authority of Zuhri but with a slight variation of wording}}
\hadithdefcmd{muslim}{5580}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَدِمَ مُعَاوِيَةُ الْمَدِينَةَ فَخَطَبَنَا وَأَخْرَجَ كُبَّةً مِنْ شَعَرٍ فَقَالَ مَا كُنْتُ أُرَى أَنَّ أَحَدًا يَفْعَلُهُ إِلاَّ الْيَهُودَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَلَغَهُ فَسَمَّاهُ الزُّورَ ‏.‏\hadithno{5580}\hadithtrans{Sa'id b. Musayyib reported:Mu'awiya came to Medina and he addressed us and he took out a bunch of hair and said: What do I see that one of you does but that what the Jews did? (I can well recall) that when this act (adding of artificial hair) reached Allah's Messenger (ﷺ), he named it as cheating}}
\hadithdefcmd{muslim}{5581}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ أَخْبَرَنَا مُعَاذٌ، - وَهُوَ ابْنُ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ مُعَاوِيَةَ، قَالَ ذَاتَ يَوْمٍ إِنَّكُمْ قَدْ أَحْدَثْتُمْ زِيَّ سَوْءٍ وَإِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الزُّورِ ‏.‏ قَالَ وَجَاءَ رَجُلٌ بِعَصًا عَلَى رَأْسِهَا خِرْقَةٌ قَالَ مُعَاوِيَةُ أَلاَ وَهَذَا الزُّورُ ‏.‏ قَالَ قَتَادَةُ يَعْنِي مَا يُكَثِّرُ بِهِ النِّسَاءُ أَشْعَارَهُنَّ مِنَ الْخِرَقِ ‏.‏\hadithno{5581}\hadithtrans{Sa, id b. Musayyib reported that Mu'awiya said one day:Should I narrate to you the evil make-up. Allah's Apostle (ﷺ) forbade cheating. It was during that time that a person came with a staff and there was a cloth on its head, whereupon Mu, awiya said: Behold, that is cheating. Qatada said: This implies how women artificially increase their hair with the help of rags}}
\hadithdefcmd{muslim}{5582}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صِنْفَانِ مِنْ أَهْلِ النَّارِ لَمْ أَرَهُمَا قَوْمٌ مَعَهُمْ سِيَاطٌ كَأَذْنَابِ الْبَقَرِ يَضْرِبُونَ بِهَا النَّاسَ وَنِسَاءٌ كَاسِيَاتٌ عَارِيَاتٌ مُمِيلاَتٌ مَائِلاَتٌ رُءُوسُهُنَّ كَأَسْنِمَةِ الْبُخْتِ الْمَائِلَةِ لاَ يَدْخُلْنَ الْجَنَّةَ وَلاَ يَجِدْنَ رِيحَهَا وَإِنَّ رِيحَهَا لَيُوجَدُ مِنْ مَسِيرَةِ كَذَا وَكَذَا ‏"‏ ‏.‏\hadithno{5582}\hadithtrans{AbU Huraira reported Allah's Messenger (ﷺ) having said this:Two are the types of the denizens of Hell whom I did not see: people having flogs like the tails of the ox with them and they would be beating people, and the women who would be dressed but appear to be naked, who would be inclined (to evil) and make their husbands incline towards it. Their heads would be like the humps of the bukht camel inclined to one side. They will not enter Paradise and they would not smell its odour whereas its odour would be smelt from such and such distance}}
\hadithdefcmd{muslim}{5583}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، وَعَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، قَالَتْ يَا رَسُولَ اللَّهِ أَقُولُ إِنَّ زَوْجِي أَعْطَانِي مَا لَمْ يُعْطِنِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُتَشَبِّعُ بِمَا لَمْ يُعْطَ كَلاَبِسِ ثَوْبَىْ زُورٍ ‏"‏ ‏.‏\hadithno{5583}\hadithtrans{A'isha reported that a woman said:Allah's Messenger, may I say to my (co-wife) that my husband has given me (such and such) a thing but which he has not in fact gives me? 'Thereupon Allah's Messenger (ﷺ) said: The one who makes a false statement of that which one has not been given is like one who wears a garment of falsehood}}
\hadithdefcmd{muslim}{5584}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدَةُ، حَدَّثَنَا هِشَامٌ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِنَّ لِي ضَرَّةً فَهَلْ عَلَىَّ جُنَاحٌ أَنْ أَتَشَبَّعَ مِنْ مَالِ زَوْجِي بِمَا لَمْ يُعْطِنِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُتَشَبِّعُ بِمَا لَمْ يُعْطَ كَلاَبِسِ ثَوْبَىْ زُورٍ ‏"‏ ‏.‏\hadithno{5584}\hadithtrans{Asma' reported that a woman came to Allah's Apostle (ﷺ) and said:I have a co-wife. Is there any harm for me if I give her the false impression (of getting something from my husband which he has not in fact given me)? Thereupon Allah's Messenger (ﷺ) said: The one who creates such a (false impression) of receiving what one has not been given is like one who wears the garment of falsehood}}
\hadithdefcmd{muslim}{5585}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، كِلاَهُمَا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5585}\hadithtrans{This hadith has been reported on the authority of Hisham with the same chain of transmitters}}
